; READ THIS FIRST:
; make sure that the following files are placed in the same folder as the Netlogo model:
; Spatial datafiles: [neighbourhood].shp (buildings) and address_[neighbourhood].shp (households)
; .csv datafiles: "Data/Warmteverbruik/Warmteverbruik.csv" "Data/Huishoudens.csv" "Data/Renovation_costs_single_family.csv" "Data/Renovation_costs_apartments.csv" "Data/Huurverhoging.csv"

extensions [csv gis table]

breed [households household]
breed [buildings building]

globals [
  ; map
  building-dataset ; to import the building dataset (BAG shapefile)
  address-dataset ; to import the addresses dataset (BAG shapefile)
  heat-dataset ; to import the heat demand dataset (.csv file)
  household-dataset ; to import the household data (.csv file)
  costs-single-dataset ; costs to increase energy label of single-family  homes
  costs-apartment-dataset ; costs to increase energy label of apartments
  rent-increase-dataset ; rent increases following dwelling quality improvements

  ; demographic
  total_households ; total nr of households
  fraction_renters
  corporation_ownership ; fraction of dwellings owned by housing corporations
  total_proxy_labels ; nr of households that were assigned a proxy label

  ; energy
  gas_price_0 ; initial gas price (at t=0) in €/GJ
  gas_price ; current gas price in €/GJ
  electricity_price_0 ; initial electricity price (at t=0) in €/GJ
  electricity_price ; current electricity price in €/GJ
  heat_price ; current heat price in €/GJ
  mean_heat_use ; average household heat demand in GJ/year
  mean_energy_use ; average household energy use in GJ/year
  mean_heat_expenses
  mean_electricity_expenses

  eff_sh
  eff_tw

  VAT
  fixed_costs_electricity
  fixed_costs_gas
  fixed_costs_heat
  variable_costs_electricity
  variable_costs_gas
  variable_costs_gas_high
  variable_costs_heat
  tax_reduction

  ; social conversion factors
  avg_income
  sd_income
  mean_income
  mean_income_NL
  social_minimum
  avg_equity
  gini-income
  income_groups

  ; Dependent variables
  mean_fraction_income_to_heat ; the average fraction of household income going to heat expenses
  mean_energy_expenses ; the mean energy expenses of all households
  mean_energy_expenses_0 ; " at start of scenario
  fraction_connected ; fraction of households connected to the heat network
  fraction_unaffordable ; fraction of households wanting to connect but cannot pay for it
  fraction_voucher ; fraction of households using voucher to connect to heat network

  mean_EQ ; mean energy quote of households
  gini-EQ ; gini index of energy quotes of households
  gini-ee ; gini of energy expenses
  ginis ; list of all gini coefficients

  ; groups having energy poverty
  fraction_renters_ep ; fraction of households with energy poverty that are renters for each type of energy poverty
  mean_energy_use_ep ; mean energy use for each type of energy poverty
  mean_income_ep ; mean income for each type of energy poverty
  income_groups_ep ; fraction of households with ep belonging to each income group for each type of ep
  household_type_ep ; fraction of households with ep belonging to each household type for each type of ep
  dwelling_category_ep ; fraction of households with ep belonging to each dwelling category for each type of ep
  energy_labels_ep ; fraction of households with ep belonging to each energy label for each type of ep

  ; energy poverty within groups
  ep_homeownership
  ep_income_groups
  ep_household_types
  ep_dwelling_categories
  ep_energy_labels

  fraction_renters_hn
  mean_energy_use_hn
  mean_income_hn
  income_groups_hn
  household_type_hn
  dwelling_category_hn
  energy_labels_hn

  ; other metrics
  mean_energy_label
  mean_join
  mean_subsidised

  ; key energy poverty indicators: mean levels for all households
  LI;
  LEQ
  HEQ
  LIHC
  LILEQ
  LILEQ-
  LILEQ+
  oLEQ
  rLEQ
  energy_poverty ; list of all energy poverty indicators

  ; Lorenz graphs and GINI coefficients
  gini-index-reserve
  lorenz-points
  gini-index-reserve-income
  lorenz-points-income
  gini-index-reserve-ee
  lorenz-points-ee

  ; for graphs
  counts ; counts of each energy label
  labels ; names of the energy labels present
  n ; highest count of energy label
  dwelling_counts
  dwelling_labels
  dwelling_n
  rvo_counts
  rvo_labels
  rvo_n
  proxy_counts
  proxy_labels
  proxy_n
  household_counts
  household_labels
  household_n
  age_counts
  age_labels
  age_n
  age_category_counts
  age_category_labels
  age_category_n
  income_counts
  income_labels
  income_n

  months ;  total running time of model (ticks)
]

buildings-own [
  ; from input data
  nr_households ; number of dwellings in building
  buildingid ; object ID of the building from the BAG dataset
  bouwjaar ; year of construction
  total_floorspace ; total floor area of building

  ; assigned or determined in model
  heating_system ; type of heating system present in the building
  building_connected? ; whether the building is connected to the heat network
  owner ; whether the building is privately owned or corporation-owned
]

households-own [
  ; key energy poverty indicators
  HEQ?
  LIHC?
  LILEQ?
  LILEQ-?
  LILEQ+?
  oLEQ?
  rLEQ?

  ; dwelling
  objectid ; object ID from BAG dataset
  buildingid ; object ID of the building containing the dwelling from BAG dataset
  ownership ; owner/renter
  floorspace ; dwelling floor area in m2
  dwelling_type ; type of dwelling (Woning_type):
  ;Appartement, Flatwoning (overig), Galerijwoning, Maisonnette, Portiekwoning, Rijwoning hoek, Rijwoning tussen,
  ;Twee-onder-een-kap, Twee-onder-een-kap / rijwoning hoek, Vrijstaande woning, Woongebouw met niet-zelfstandige woonfunctie
  dwelling_category ; less specific category for dwelling type:
  ;vrijstaand, 2 onder 1 kap, rijwoning hoek, rijwoning tussen, meergezins
  bouwjaar ; year of construction
  household_type ; type of household:
  ;Alleenstaand < 35 jr, Alleenstaand 35-64 jr, Alleenstaand 65+ jr, Paar <35 jr, Paar 35-64 jr, Paar 65+ jr, Paar met kinderen, Eenoudergezin
  heating_system ; individual or collective heating system in building

  ; economic
  income ; annual spendable income
  income_group ; 10%-group of incomes
  LI? ; whether the household is considered low-income
  equity ; amount of savings of a household
  rent ; increase in rent as a result of interventions
  LEQ? ; whether household is low energetic quality

  ; energy
  space_heating_demand ; average annual energy demand for space heating [GJ/year]
  space_heating_use
  water_demand ; average annual energy demand for warm water [GJ/year]
  water_use
  heat_demand ; average annual energy demand for space heating and warm water [GJ/year]
  heat_use ; actual heat use for space heating and warm water [GJ/year]
  electric_demand ; average annual energy demand for electric appliances [GJ/year]
  cold_demand ; average annual cold demand [GJ/year]
  energy_demand ; average annual total energy demand [GJ/year]
  electricity_use ; = actual use for electric demand + cold demand [GJ/year]
  energy_use ; actual total energy use [GJ/year]
  heat_expenses ; annual heat expenses [€/year]
  heat_expenses_exp ; annual heat expenses based on expected energy demand instead of actual use [€/year]
  electricity_expenses
  energy_expenses ; annual total energy expenses [€/year]
  energy_expenses_exp  ; annual total energy expenses based on expected energy use instead of actual use [€/year]
  energy_price ; the price this household pays per energy unit [€/GJ]
  fraction_income_to_heat ; fraction of income going to heat expenses
  fraction_income_to_heat_exp ; fraction of income going to heat expenses for expected heat demand instead of actual use
  fraction_income_to_energy ; fraction of income going to total energy expenses
  fraction_income_to_energy_exp ; fraction of income going to energy expenses for expected energy demand instead of actual use
  fraction_energy_to_heat ; fraction of total energy expenses coming from heat expenses
  energy_label ; string representation of energy label
  energy_label_num ; numerical representation of energy label, G = 0, F = 1, E = 2, D = 3, C = 4, B = 5, A = 6, A+ = 7, A++ = 8, A+++ = 9
  energy_label_initial ; string value of energy label from RVO database
  energy_label_initial_num ; numerical value of energy label assigned at start of model
  energy_label_proxy ; if the household had no known label

  renovation_costs ; costs for improving dwelling from current label to label B
  building_connected? ; whether the building is member of the heat network
  renovated? ; formerly house_changed? ; whether the energy label has been improved
  extra_expenses ; additional annual expenses

  ; personal, social, environmental conversion factors
  environmental_awareness
  susceptibility
  campaign_effect

  ; decision-making
  satisfaction ; level of satisfaction of the household
  certainty ; level of certainty of the household
  strategy ; used decision-making strategy
  choice ; choice of heating system

  unaffordable ; if household wants to connect but cannot afford
  voucher ; if household used a voucher
]


;________________________________________________________________________________________________________________________
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;     INITIALIZATION     ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to setup
  setup-map
  setup-model
end

to setup-map   ; setup GIS map and load datasets
  clear-all
  if gas_tax_high_increase < gas_tax_low_reduction [stop]

  ; load the building dataset, containing only residential buildings ('pand' shapefile from BAG with residential function)
  set building-dataset gis:load-dataset (word "Input/" buurt ".shp")
  gis:set-world-envelope (gis:envelope-of building-dataset)
  gis:set-drawing-color white
  gis:draw building-dataset 1

  ; load the address & energy label dataset ('adres' shapefile from BAG combined with energy label database)
  set address-dataset gis:load-dataset (word "Input/address_" buurt ".shp")

  ; load energy datasets
  set heat-dataset csv:from-file "Input/Warmteverbruik.csv"
  set household-dataset csv:from-file "Input/Huishoudens.csv"
  set costs-single-dataset csv:from-file "Input/Renovation_costs_single_family.csv"
  set costs-apartment-dataset csv:from-file "Input/Renovation_costs_apartments.csv"
  set rent-increase-dataset csv:from-file "Input/Huurverhoging.csv"

  ; household dataset contains distribution of household types in %, we want to replace this by cumulative sum of these % to assign households these later
  foreach [1 2] ; rows 1 and 2 contain the %
  [ x ->
  let percentages item x household-dataset
  let percentages_sum []
;    set percentages_sum remove-item 0 percentages_sum ; remove header
  let tempsum 0
  foreach percentages
  [ y ->
    ifelse is-string? y
    [ set percentages_sum lput y percentages_sum]
    [ set tempsum (tempsum + y)
      set percentages_sum lput tempsum percentages_sum
    ]
  ]
    set household-dataset (replace-item x household-dataset percentages_sum) ; replace the percentages in household dataset by cumulative percentages
  ]

  update-map
end


to setup-model ; initialize model
  ; clean up some stuff (don't use clear-all, or we'll have to import the data again)
  if gas_tax_high_increase < gas_tax_low_reduction [stop]
  ask households [die]
  reset-ticks
  clear-output
  clear-all-plots
  clear-turtles

  set months 60

  ; setup variables

  ; building variables
  ifelse buurt = "wijk_24_voorhof"
  [
    set corporation_ownership [0.47 0.43 0.49 0 0 0]
    ; apartment terraced_house corner_house 2-under-1-roof freestanding other
  ]
  [ ifelse buurt = "wijk_25_buitenhof"
    [
      set corporation_ownership [0.86 0.11 0.14 0 0 0]
    ]
    [ set corporation_ownership [0.5 0.5 0.5 0 0 0]

    ]
  ]


  ; economic / energy variables
;  set gas_price_0 41.23; initial gas price in €/GJ
;  set electricity_price_0 111 ; initial electricity price in €/GJ

  set eff_sh 1.04 ; gas central heating efficiency for space heating
  set eff_tw 0.72 ; gas central heating efficiency for warm tap water

  set mean_income_NL 48400 ; annual spendable household income of the Netherlands €
  set social_minimum [21072 15192] ; 21072 €/y for couples, 15192 €/y for singles
  set avg_equity [33800 2300] ; 33800 for homeowners, 2300 for renters

  ; setup buildings
  foreach gis:feature-list-of building-dataset [ feature ->
    let location gis:location-of gis:centroid-of feature
      create-buildings 1
      [
        set xcor item 0 location
        set ycor item 1 location
        set shape "square"
        set size 0

        set nr_households gis:property-value feature "gebr_woonf" ;; temporary; to decide if the property has multiple inhabitants. Will get correct nr of households, based on agents, later
        ifelse nr_households > 1
        [ ; for multi-household buildings:
          ifelse random-float 1 <= item 0 corporation_ownership  ; determine owner
          [ set owner "corporation" ]
          [ set owner "private" ]
          ifelse random-float 1 < share_collective_system
          [ set heating_system "collective" ]
          [ set heating_system "individual" ]
        ]
        [ ; for single-household buildings:
          set heating_system "individual" ; assume single buildings all have an individual heating system
;         ; ownership will be determined depending on dwelling type, TBD at household setup
        ]
        set buildingid gis:property-value feature "objectid"
        set building_connected? false ; no building is connected to heat network at the start
        set bouwjaar gis:property-value feature "bouwjaar"
        set total_floorspace gis:property-value feature "oppervlakt"
      ]
  ]

  ; setup households
  foreach gis:feature-list-of address-dataset [ feature ->
    let location gis:location-of gis:centroid-of feature
    if length location > 1 ; for each address with a specified location (some addresses don't have a location)
    [
      create-households 1
    [
      ; connect characteristics from dataset
      set buildingid 0
      foreach gis:feature-list-of building-dataset [ feature2 ->
        if gis:contains? feature2 feature ; if the address (feature) is within the residential building (feature2)
        [
          set buildingid gis:property-value feature2 "objectid" ; the household gets the same id as the building
          set bouwjaar gis:property-value feature2 "bouwjaar" ; the household gets the same construction year as the building
          set floorspace gis:property-value feature2 "oppervlakt" / gis:property-value feature2 "aantal_ver" ; divide by number of 'verblijfsobjecten' in building
          if floorspace > 300 [set floorspace 300] ; to remove outliers due to building having only a few dwellings and a large space of other functions
        ]
      ]

      if buildingid = 0 ; remove the addresses that are not in a residential building (and are thus not households)
      [ die ]

      let a 5

      set objectid gis:property-value feature "objectid" ; take unique address ID
      set dwelling_type gis:property-value feature "Energiel_2"
      ifelse dwelling_type = "Vrijstaande woning"
        [ set dwelling_category "vrijstaand"
          set a 4
        ]
        [ ifelse dwelling_type = "Twee-onder-een-kap"
          [ set dwelling_category "2 onder 1 kap"
            set a 3
          ]
          [ ifelse dwelling_type = "Twee-onder-een-kap / rijwoning hoek"
            [ set dwelling_category "rijwoning hoek"
              set a 2
            ]
            [ ifelse dwelling_type = "Rijwoning hoek"
              [ set dwelling_category "rijwoning hoek" ; this seems to go wrong. why?
                set a 2
              ]
              [ ifelse dwelling_type = "Rijwoning tussen"
                [ set dwelling_category "rijwoning tussen"
                  set a 1
                ]
                [ set dwelling_category "meergezins"
                  set a 0
                ] ; includes Appartement, Flatwoning, Galerijwoning, Maisonnette, Portiekwoning, Woongebouw met niet-zelfstandige woonfunctie
              ]
            ]
          ]
        ]

        ; determine ownershop
        let my_buildingid buildingid
        ifelse one-of [owner] of buildings with [buildingid = my_buildingid] = "corporation"
        [ set ownership "renter" ]
        [ ifelse one-of [owner] of buildings with [buildingid = my_buildingid] = "private"
          [ set ownership "owner" ]
          [

            ifelse random-float 1 <= item a corporation_ownership ;ownership percentages defined by dwelling category
            [ set ownership "renter"
              ask buildings with [buildingid = my_buildingid]
              [ set owner "corporation" ]
            ]
            [ set ownership "owner"
              ask buildings with [buildingid = my_buildingid]
              [ set owner "private" ]
            ]
          ]
        ]

      set xcor item 0 location
      set ycor item 1 location
      set shape "circle"
      set size 0.4

      ; note: two values are available for energy label in the RVO dataset. The field "Energielab"
      set energy_label_initial gis:property-value feature "Energielab" ; assign energy label based on energy label database
        ifelse energy_label_initial = "" [set energy_label_num 999] ; temporary value, a proxy label will be fixed later
        [ if energy_label_initial = "G" [set energy_label_num 0]
          if energy_label_initial = "F" [set energy_label_num 1]
          if energy_label_initial = "E" [set energy_label_num 2]
          if energy_label_initial = "D" [set energy_label_num 3]
          if energy_label_initial = "C" [set energy_label_num 4]
          if energy_label_initial = "B" [set energy_label_num 5]
          if first energy_label_initial = "A" [set energy_label_num 6 set energy_label_initial "A"] ; cluster all labels >= A
        ]
;        if energy_label_initial = "A+" [set energy_label_num 7]
;        if energy_label_initial = "A++" [set energy_label_num 8]
;        if energy_label_initial = "A+++" [set energy_label_num 9]

      ; set other characteristics
      set building_connected? false ; assume no heat network exists yet
      set renovated? false

        set heating_system item 0 [heating_system] of buildings with [buildingid = [buildingid] of myself]


        ; determine household demographic & economic factors
        set income 0

        let row_nr 0
        if ownership = "renter"
        [ set row_nr 1
          let mean_equity_data item 1 avg_equity
          let sd_equity_data mean_equity_data / 3
          set equity random-normal mean_equity_data sd_equity_data
        ]
        if ownership = "owner"
        [ set row_nr 2
          let mean_equity_data item 0 avg_equity
          let sd_equity_data mean_equity_data / 3
          set equity random-normal mean_equity_data sd_equity_data
        ]
        let column_nr 1
        let randomnr random 100
        foreach item row_nr household-dataset
        [ x ->
          ifelse is-string? x
          []
          [
          ifelse randomnr <= x ; assign a household type based on the distribution of household types in the NL
          [ set household_type item column_nr item 0 household-dataset
            let mean_income_data item column_nr item 3 household-dataset ; row 3 is mean monthly spendable income per household type
            let sd_income_data mean_income_data / 3 ; assumption
            let income_monthly random-normal (mean_income_data) sd_income_data  ; this is monthly income
            let income_temp 12 * income_monthly ; annual income, can be negative or 0
              ifelse income_temp < 1 [set income 1]
              [set income income_temp] ; annual spendable household income. We set those with no income to 1 to allow further calculations.
          ]
          [ set column_nr column_nr + 1]
          ]
        ]

        ; determine income groups
        ifelse income <= 17200 [ set income_group "0-10%" ]
        [ ifelse income <= 22500 [ set income_group "10-20%" ]
          [ ifelse income <= 27700 [ set income_group "20-30%" ]
            [ ifelse income <= 33100 [ set income_group "30-40%" ]
              [ ifelse income <= 39500 [ set income_group "40-50%" ]
                [ ifelse income <= 47500 [ set income_group "50-60%" ]
                  [ ifelse income <= 56600 [ set income_group "60-70%" ]
                    [ ifelse income <= 67500 [ set income_group "70-80" ]
                      [ ifelse income <= 85000 [ set income_group "80-90%" ]
                        [ set income_group "90-100%" ]
                      ]
                    ]
                  ]
                ]
              ]
            ]
          ]
        ]

        ; determine if low-income
        let my_social_minimum 0
        ifelse first household_type = "P" [set my_social_minimum item 0 social_minimum] ;  all couple types ("Paar [...]")
        [set my_social_minimum item 1 social_minimum] ; single-persons
        ifelse income < my_social_minimum * 1.3 [set LI? true] ; low-income if income is lower than 130% of social minimum
        [ set LI? false ]

        ; personal conversion factors
        set environmental_awareness random-float 1
        set susceptibility random-float 1

        ; awareness campaign
        set campaign_effect 0

      ]
    ]
  ]

  set total_proxy_labels count households with [energy_label_num = 999] ; keep track of how many households had no energy label determined
  ask households with [energy_label_num = 999] ; if the energy label is unknown (not in database), assign one...
  [
    ifelse bouwjaar >= 2015 ; for recent buildings we can estimate label based on year of construction
    [
      if bouwjaar < 2020
      [ set energy_label_num 5
        set energy_label_proxy "B"
      ]
      if bouwjaar >= 2020
      [ set energy_label_num 6
        set energy_label_proxy "A"]
    ]
    [ ; for older buildings, assume same label as closest neighbour that has a known energy label
      set energy_label_num [energy_label_num] of min-one-of households with [energy_label_num < 999] [distance myself]
      if energy_label_num = 0 [set energy_label_proxy "G"]
      if energy_label_num = 1 [set energy_label_proxy "F"]
      if energy_label_num = 2 [set energy_label_proxy "E"]
      if energy_label_num = 3 [set energy_label_proxy "D"]
      if energy_label_num = 4 [set energy_label_proxy "C"]
      if energy_label_num = 5 [set energy_label_proxy "B"]
      if energy_label_num = 6 [set energy_label_proxy "A"]
      if energy_label_num = 7 [set energy_label_proxy "A+"]
      if energy_label_num = 8 [set energy_label_proxy "A++"]
      if energy_label_num = 9 [set energy_label_proxy "A+++"]
    ]
  ]

  ask households with [dwelling_type = ""]
  [
    ;assume same dwelling type as closest neighbour that has a known dwelling type
    set dwelling_type [dwelling_type] of min-one-of households with [dwelling_type != ""] [distance myself]
  ]

  ask buildings ; determine how many households are in a building
  [
    let my_buildingid buildingid
    set nr_households count households with [buildingid = my_buildingid]
  ]

  ; energy demand
  ask households
  [
    ; remember original energy label (in numerical values for histogram)
    if energy_label_num = 0 [set energy_label_initial_num 0 set energy_label "G"]
    if energy_label_num = 1 [set energy_label_initial_num 1 set energy_label "F"]
    if energy_label_num = 2 [set energy_label_initial_num 2 set energy_label "E"]
    if energy_label_num = 3 [set energy_label_initial_num 3 set energy_label "D"]
    if energy_label_num = 4 [set energy_label_initial_num 4 set energy_label "C"]
    if energy_label_num = 5 [set energy_label_initial_num 5 set energy_label "B"]
    if energy_label_num = 6 [set energy_label_initial_num 6 set energy_label "A"]
    if energy_label_num = 7 [set energy_label_initial_num 7 set energy_label "A+"]
    if energy_label_num = 8 [set energy_label_initial_num 8 set energy_label "A++"]
    if energy_label_num = 9 [set energy_label_initial_num 9 set energy_label "A+++"]

    calculate-energy-demand

    ; determine costs for renovating dwellings with LEQ to label B
    if energy_label_num < 4
    [
      let to-label 3 ; 2nd column of renovation cost data table
      let from-label 1 + energy_label_num ; G is on 2nd row, etc

      set LEQ? true
      ifelse dwelling_category = "meergezins" ; renovation costs are set for apartments or low-rise dwellings in €/m2
      [ set renovation_costs floorspace * item to-label item from-label costs-apartment-dataset ]
      [ set renovation_costs floorspace * item to-label item from-label costs-single-dataset ]

    ]
  ]


  set total_households count households
  set mean_income mean [income] of households
  set income_groups table:to-list table:counts [income_group] of households with [LEQ? = true]
  set income_groups (sort-by [ [a b] -> first a < first b ] income_groups)
  set LI count households with [LI? = true] / total_households
  set LEQ count households with [LEQ? = true] / total_households
  set fraction_renters count households with [ownership = "renter"] / total_households

  energy-prices

  ; plots setup
  plots-setup
  setup-plots

  if update-map? = true
  [ update-map ]

end

;________________________________________________________________________________________________________________________
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;     GO: RUNNING THE MODEL     ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go
  if gas_tax_high_increase < gas_tax_low_reduction [stop]

  ; connect eligible buildings to heat network (per year)
  if heat_network_implementation != "none"
  [ heat-network-implementation ]

  ; renovate buildings with low energy efficiency (per year)
  if other_intervention = "improve energy efficiency"
  [ renovation ]

  if other_intervention = "awareness campaign"
  [ awareness-campaign ]

  ; household energy use and decision for heat network is assessed yearly
  household-decision-making

  ; calculate indicators for energy poverty and inequality
  energy-poverty-indicators
  update-lorenz-and-gini

  ; update map
  if update-map? = true
  [ update-map ]

  if ticks >= months [
    final-reporters
    stop]

  tick ; one tick equals one month

end

;________________________________________________________________________________________________________________________

to calculate-energy-demand
  ; determine energy demand, depending on FLOORSPACE, DWELLING CATEGORY, BUILDING AGE, and mean energy use table
    let base_heat_demand 0
    let variable_heat_demand 0
    let variable_cold_demand 0
      ; column 0 = type
      ; column 1 = year
      ; column 2+3 = heat demand for label unknown, base demand + demand per m2
      ; column 4+5 = heat demand for label G (energy_label 0), base demand + demand per m2
      ; column 6+7 = heat demand for label F (energy_label 1), base demand + demand per m2
      ; column 8+9 = heat demand for label E (energy_label 2), base demand + demand per m2
      ; column 10+11 = heat demand for label D (energy_label 3), base demand + demand per m2
      ; column 12+13 = heat demand for label C (energy_label 4), base demand + demand per m2
      ; column 14+15 = heat demand for label B (energy_label 5), base demand + demand per m2
      ; column 16+17 = heat demand for label A+ (energy_label 6-9), base demand + demand per m2
    let column_nr (energy_label_num + 2) * 2
      if column_nr > 16 [ set column_nr 16 ] ; all energy labels above A will have the heat demand defined for labels 'A+' in dataset
    let row_nr 0

    ; structure of heat-dataset:
    ; row 0-1 = headers
    ; so row 2-12 is vrijstaand
    ; row 13-23 is 2 onder 1 kap
    ; row 24-34 is rijwoning hoek
    ; row 35-45 is rijwoning tussen
    ; row 46-56 is meergezins
    if dwelling_category = "vrijstaand"
    [ set row_nr row_nr + 2 ]
    if dwelling_category = "2 onder 1 kap"
    [ set row_nr row_nr + 13 ]
    if dwelling_category = "rijwoning hoek"
    [ set row_nr row_nr + 24 ]
    if dwelling_category = "rijwoning tussen"
    [ set row_nr row_nr + 35 ]
    if dwelling_category = "meergezins"
    [ set row_nr row_nr + 46 ]
      ; 11 different building age groups are defined
      ifelse bouwjaar < 1930
      []
      [ ifelse bouwjaar < 1946
        [ set row_nr row_nr + 1 ]
        [ ifelse bouwjaar < 1965
          [ set row_nr row_nr + 2 ]
          [ ifelse bouwjaar < 1975
            [ set row_nr row_nr + 3 ]
            [ ifelse bouwjaar < 1992
              [ set row_nr row_nr + 4 ]
              [ ifelse bouwjaar < 1996
                [ set row_nr row_nr + 5 ]
                [ ifelse bouwjaar < 2000
                  [ set row_nr row_nr + 6 ]
                  [ ifelse bouwjaar < 2006
                    [ set row_nr row_nr + 7 ]
                    [ ifelse bouwjaar < 2011
                      [ set row_nr row_nr + 8 ]
                      [ ifelse bouwjaar < 2015
                        [ set row_nr row_nr + 9 ]
                        [ if bouwjaar > 2014
                          [ set row_nr row_nr + 10 ]
                        ]
                      ]
                    ]
                  ]
                ]
              ]
            ]
          ]
        ]
      ]

    set base_heat_demand item column_nr item row_nr heat-dataset ; base annual heat demand [GJ/aansl (connection)]
    set variable_heat_demand item (column_nr + 1) item row_nr heat-dataset ; variable annual heat demand per m2 [GJ/m2]
    set space_heating_demand base_heat_demand + floorspace * variable_heat_demand ; annual heat demand [GJ]

    ; water demand: column 18 (GJ/connection)
    set water_demand item 18 item row_nr heat-dataset ; annual warm water demand [GJ]
    set heat_demand space_heating_demand + water_demand
    ; electric appliance electricity demand: column 20 (GJ/connection)
    set electric_demand item 20 item row_nr heat-dataset ; annual energy demand for electric appliances [GJ]
    ; cold demand: column 23 (GJ/m2)
    set variable_cold_demand item 23 item row_nr heat-dataset ; variable annual cold demand per m2 [GJ/m2]
    set cold_demand floorspace * variable_cold_demand ; annual cold demand [GJ]

    set energy_demand space_heating_demand + water_demand + electric_demand + cold_demand ; annual total energy demand [GJ]
end


to energy-prices
  ; electricity and gas prices exclude VAT
  ; heat prices include VAT
  set VAT 0.21

  if energy_prices = "2023 regulated prices"
  [ set fixed_costs_electricity 220 + 61 ; fixed costs €/y
    set fixed_costs_gas 152 + 59 ; fixed costs €/y
;    ifelse include-extra-costs? = true
;    [ set fixed_costs_heat (478.60 + 125.50) * heat-cost-relative-to-max ]
;    [ set fixed_costs_heat (478.60) * heat-cost-relative-to-max ] ; fixed costs €/y
    set fixed_costs_heat (478.60) * heat-cost-relative-to-max

    set variable_costs_electricity 0.40 / 0.0036 ; €/GJ -> 0.40 €/kWh / 0.0036 GJ/kWh
    set variable_costs_gas 1.45 / 0.03517 ; €/GJ -> 1.45 €/m3 / 35.17 MJ/m3 * 1000 MJ/GJ
    set variable_costs_heat (47.39) * heat-cost-relative-to-max ; €/GJ

    set tax_reduction 682 ; €/y
  ]
  if energy_prices = "2021 prices"
  [ set fixed_costs_electricity 209 + 58
    set fixed_costs_gas 152 + 57
;    ifelse include-extra-costs? = true
;    [ set fixed_costs_heat (478.60 + 125.50) * heat-cost-relative-to-max ]
;    [ set fixed_costs_heat (478.60) * heat-cost-relative-to-max ]
    set fixed_costs_heat (478.60) * heat-cost-relative-to-max

    set variable_costs_electricity (0.07 + 0.09 + 0.03) / 0.0036 ; €/GJ
    set variable_costs_gas (0.25 + 0.34 + 0.08) / 0.03517 ; €/GJ
    set variable_costs_heat (25.51) * heat-cost-relative-to-max

    set tax_reduction 453
  ]
  if energy_prices = "2020 prices"
  [ set fixed_costs_electricity 200 + 57
    set fixed_costs_gas 153 + 56
;    ifelse include-extra-costs? = true
;    [ set fixed_costs_heat (469.17 + 126.19) * heat-cost-relative-to-max ]
;    [ set fixed_costs_heat (469.17) * heat-cost-relative-to-max ]
    set fixed_costs_heat (469.17) * heat-cost-relative-to-max

    set variable_costs_electricity (0.06 + 0.10 + 0.03) / 0.0036 ; €/GJ
    set variable_costs_gas (0.23 + 0.34 + 0.08) / 0.03517 ; €/GJ
    set variable_costs_heat (26.06) * heat-cost-relative-to-max

    set tax_reduction 436
  ]
  if energy_prices = "2019 prices"
  [ set fixed_costs_electricity 198 + 55
    set fixed_costs_gas 147 + 55
;    ifelse include-extra-costs? = true
;    [ set fixed_costs_heat (318.95 + 126) * heat-cost-relative-to-max ]
;    [ set fixed_costs_heat (318.95) * heat-cost-relative-to-max ]
    set fixed_costs_heat (318.95) * heat-cost-relative-to-max

    set variable_costs_electricity (0.07 + 0.10 + 0.02) / 0.0036 ; €/GJ
    set variable_costs_gas (0.29 + 0.29 + 0.05) / 0.03517 ; €/GJ
    set variable_costs_heat (28.47) * heat-cost-relative-to-max

    set tax_reduction 258
  ]

  if financial_intervention = "energy tax" or financial_intervention = "energy tax and vouchers"
  [ set variable_costs_gas_high variable_costs_gas + ( gas_tax_high_increase / 0.03517)
    set variable_costs_gas variable_costs_gas - ( gas_tax_low_reduction / 0.03517)
  ]

end

;________________________________________________________________________________________________________________________
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;     DECISION MAKING    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to household-decision-making
  ; household make energy-related decisions: how much heat will they use this year?
  ; assessed monthly
  if ticks mod 12 = 0
  [
    ask households
    [
      ; determine actual energy use based on average heat demand of particular house and personal preferences
      ; calculate individual conversion factors
      let c_env 0
      ifelse energy_consumption_factors = "no heterogeneity"
      [ set c_env 1 ]
      [ set c_env 1.2 - 0.4 * environmental_awareness ] ; the higher the awareness, the lower the energy use (up to 80% predicted use)
      let c_inc 0
      ifelse energy_consumption_factors = "income affects heat use"
      [ set c_inc 0.75 + 0.5 / (1 + exp(-2 * (income / mean_income_NL - 1))) ] ; the lower the income, the lower the heat use (up to 75% - 125% of predicted use)
      [ set c_inc 1 ]; assume no effect of income on energy use

      ifelse building_connected?
      [
        set space_heating_use space_heating_demand * c_env * c_inc * (1 - campaign_effect)
        set water_use water_demand * c_env * c_inc * (1 - campaign_effect)
      ]
      [
        set space_heating_use space_heating_demand * c_env * c_inc * (1 - campaign_effect) / eff_sh
        set water_use water_demand * c_env * c_inc * (1 - campaign_effect) / eff_tw
      ]
      set heat_use space_heating_use + water_use ; annual heat consumption
      set electricity_use (electric_demand + cold_demand) * c_env * (1 - campaign_effect) ; annual electricity consumption
      set energy_use heat_use + electricity_use ; annual energy consumption

      ; calculate energy expenses
      ifelse building_connected? ; heat expenses depend on heating system (gas or heat network)
      [ set heat_expenses fixed_costs_heat + heat_use * variable_costs_heat ] ; no VAT, already included in heat prices
      [ ; for gas-based energy systems, price depends on scenario for gas energy tax
        ifelse financial_intervention = "energy tax" or financial_intervention = "energy tax and vouchers"
        [
          if heat_use <= threshold-use
          [
            set heat_expenses (fixed_costs_gas + heat_use * variable_costs_gas) * (1 + VAT)
          ]
          if heat_use > threshold-use
          [
            set heat_expenses (fixed_costs_gas + threshold-use * variable_costs_gas + (heat_use - threshold-use) * variable_costs_gas_high) * (1 + VAT)
          ]
        ]
        [
          set heat_expenses (fixed_costs_gas + heat_use * variable_costs_gas) * (1 + VAT)
        ]
      ]
      set electricity_expenses (fixed_costs_electricity + electricity_use * variable_costs_electricity - tax_reduction) * (1 + VAT)
      set energy_expenses heat_expenses + electricity_expenses
      if include-extra-costs? = true
      [ set energy_expenses energy_expenses + extra_expenses ]

      set fraction_income_to_heat heat_expenses / income
      set fraction_income_to_heat_exp heat_expenses_exp / income
      if fraction_income_to_heat > 1 [set fraction_income_to_heat 1] ; otherwise you can get something like 300x income if income is very small)
      if fraction_income_to_heat_exp > 1 [set fraction_income_to_heat_exp 1]
      set energy_price heat_expenses / heat_use ; is only price for heat, not electricity
      set fraction_income_to_energy energy_expenses / income
      set fraction_income_to_energy_exp energy_expenses_exp / income
      if fraction_income_to_energy > 1 [set fraction_income_to_energy 1] ; otherwise you can get something like 300x income if income is very small)
      if fraction_income_to_energy_exp > 1 [set fraction_income_to_energy_exp 1]
      ; energy price
      set fraction_energy_to_heat heat_expenses / energy_expenses
    ]
  ]

  ; energy system decision-making: what heating system do they choose?
  ; assessed yearly
  if ticks mod 12 = 0
  [
    ask households with [ownership = "owner"] ; unfortunately renters don't get to choose
    [
      if building_connected? = false ; if the household is already connected to the heat network, it cannot switch back anymore
      [
        if decision_making = "model of consumer behaviour"
        [
          ; determine satisfaction
          ifelse LIHC? = true or LILEQ? = true or oLEQ? = true
          [ set satisfaction 0]
          [ set satisfaction 1]
          ; determine certainty level

          set certainty environmental_awareness + ( campaign_effect / 2 )

          if satisfaction = 1 and certainty >= 0.5
          [
            set strategy "repetition" ; the household will continue to use the same heating system
            set choice "no heat network"
          ]
          if satisfaction = 0 and certainty >= 0.5
          [
            set strategy "deliberation" ; the household will choose heat network if it can afford it

            ifelse equity > 40000 [ set choice "heat network" ]
            [
              ifelse LI?
              [
                ifelse financial_intervention = "vouchers" OR financial_intervention = "energy tax and vouchers"
                [ set choice "heat network"
                  set voucher true
                ]
                [ set choice "no heat network"
                  set unaffordable true
                ]
              ]
              [
                let connection_fee 0
                ; if not low income, but equity < 40000, assume to connect when equity is at least 3x the cost of heat network connection
                ifelse dwelling_type = "meergezins" [ set connection_fee connection_fee_apartments ]
                [ set connection_fee connection_fee_lowrise ]
                ifelse equity >= 3 * connection_fee [ set choice "heat network" ]
                [ set choice "no heat network"
                  set unaffordable true
                ]
              ]
            ]
          ]
          if satisfaction = 1 and certainty < 0.5
          [
            set strategy "imitation" ; the household will choose the heating system that the majority of its closest 10 neighbours have. if they can afford it
            let neighbour_connected table:counts [building_connected?] of min-n-of 10 households [distance myself]
            ifelse table:get-or-default neighbour_connected "true" 0 >= table:get-or-default neighbour_connected "false" 0
            [ ; if most neighbours are connected to heat network, connect if you can afford it:
              ifelse equity > 40000 [ set choice "heat network" ]
              [
                ifelse LI?
                [
                  ifelse financial_intervention = "vouchers" OR financial_intervention = "energy tax and vouchers"
                  [ set choice "heat network"
                    set voucher true
                  ]
                  [ set choice "no heat network"
                    set unaffordable true
                  ]
                ]
                [
                  let connection_fee 0
                  ; if not low income, but equity < 40000, assume to connect when equity is at least 3x the cost of heat network connection
                  ifelse dwelling_type = "meergezins" [ set connection_fee connection_fee_apartments ]
                  [ set connection_fee connection_fee_lowrise ]
                  ifelse equity >= 3 * connection_fee [ set choice "heat network" ]
                  [ set choice "no heat network"
                    set unaffordable true
                  ]
                ]
              ]
            ]
            [ ; if most neighbours are not connected to heat network:
              set choice "no heat network"
            ]
          ]
          if satisfaction = 0 and certainty < 0.5
          [
            set strategy "social comparison" ; the household will choose the heating system that the majority of its 10 closest comparable neighbours have. if they can afford it
            let my_household household_type
            let neighbour_connected table:counts [building_connected?] of min-n-of 10 households with [household_type = my_household] [distance myself]
            ifelse table:get-or-default neighbour_connected "true" 0 >= table:get-or-default neighbour_connected "false" 0
            [ ; if most neighbours are connected to heat network, connect if you can afford it:
              ifelse equity > 40000 [ set choice "heat network" ]
              [
                ifelse LI?
                [
                  ifelse financial_intervention = "vouchers" OR financial_intervention = "energy tax and vouchers"
                  [ set choice "heat network"
                    set voucher true
                  ]
                  [ set choice "no heat network"
                    set unaffordable true
                  ]
                ]
                [
                  let connection_fee 0
                  ; if not low income, but equity < 40000, assume to connect when equity is at least 3x the cost of heat network connection
                  ifelse dwelling_type = "meergezins" [ set connection_fee connection_fee_apartments ]
                  [ set connection_fee connection_fee_lowrise ]
                  ifelse equity >= 3 * connection_fee [ set choice "heat network" ]
                  [ set choice "no heat network"
                    set unaffordable true
                  ]
                ]
              ]
            ]
            [ ; if most neighbours are not connected to heat network:
              set choice "no heat network"
            ]
          ]
        ]
        ;alternative conceptualisation for decision-making
        if decision_making = "all deliberate"
        [
          set strategy "deliberation" ; the household will choose heat network if it can afford it
          ifelse equity > 40000 [ set choice "heat network" ]
          [
            ifelse LI?
            [
              ifelse financial_intervention = "vouchers" OR financial_intervention = "energy tax and vouchers"
              [ set choice "heat network"
                set voucher true
              ]
              [ set choice "no heat network"
                set unaffordable true
              ]
            ]
            [
              let connection_fee 0
              ; if not low income, but equity < 40000, assume to connect when equity is at least 3x the cost of heat network connection
              ifelse dwelling_type = "meergezins" [ set connection_fee connection_fee_apartments ]
              [ set connection_fee connection_fee_lowrise ]
              ifelse equity >= 3 * connection_fee [ set choice "heat network" ]
              [ set choice "no heat network"
                set unaffordable true
              ]
            ]
          ]
        ]
        ;alternative conceptualisation for decision-making
        if decision_making = "coin flip"
        [
          set strategy "coin flip"
          let coin random 2
          ifelse coin = 0
          [ set choice "no heat network" ]
          [ ifelse equity > 40000 [ set choice "heat network" ]
            [
              ifelse LI?
              [
                ifelse financial_intervention = "vouchers" OR financial_intervention = "energy tax and vouchers"
                [ set choice "heat network"
                  set voucher true
                ]
                [ set choice "no heat network"
                  set unaffordable true
                ]
              ]
              [
                let connection_fee 0
                ; if not low income, but equity < 40000, assume to connect when equity is at least 3x the cost of heat network connection
                ifelse dwelling_type = "meergezins" [ set connection_fee connection_fee_apartments ]
                [ set connection_fee connection_fee_lowrise ]
                ifelse equity >= 3 * connection_fee [ set choice "heat network" ]
                [ set choice "no heat network"
                  set unaffordable true
                ]
              ]
            ]
          ]
        ]
      ]
    ]
  ]
end

;________________________________________________________________________________________________________________________
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;     CALCULATING REPORTERS     ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to energy-poverty-indicators
  set mean_energy_use mean [energy_use] of households
  set mean_fraction_income_to_heat mean [fraction_income_to_heat] of households
  set mean_energy_expenses mean [energy_expenses] of households
  if ticks = 0 [set mean_energy_expenses_0 mean_energy_expenses]
  set mean_EQ mean [fraction_income_to_energy] of households

  let energy_use_apartments_low 0
  let energy_use_apartments_high 0
  let energy_use_row_corner_low 0
  let energy_use_row_corner_high 0
  let energy_use_rowhouse_low 0
  let energy_use_rowhouse_high 0
  let energy_use_free_low 0
  let energy_use_free_high 0

  let apartments count households with [dwelling_category = "meergezins"]
  if apartments > 0
  [ let energy_use_apartments sort [energy_use] of households with [dwelling_category = "meergezins"]
    set energy_use_apartments_low item (apartments / 4) energy_use_apartments
    set energy_use_apartments_high item (3 * apartments / 4) energy_use_apartments
  ]
  let row_corner count households with [dwelling_category = "rijwoning hoek"]
  if row_corner > 0
  [ let energy_use_row_corner sort [energy_use] of households with [dwelling_category = "rijwoning hoek"]
    set energy_use_row_corner_low item (row_corner / 4) energy_use_row_corner
    set energy_use_row_corner_high item (3 * row_corner / 4) energy_use_row_corner
  ]
  let rowhouse count households with [dwelling_category = "rijwoning tussen"]
  if rowhouse > 0
  [ let energy_use_rowhouse sort [energy_use] of households with [dwelling_category = "rijwoning tussen"]
    set energy_use_rowhouse_low item (row_corner / 4) energy_use_rowhouse
    set energy_use_rowhouse_high item (3 * row_corner / 4) energy_use_rowhouse
  ]
  let free count households with [dwelling_category = "vrijstaand"]
  if free > 0
  [ let energy_use_free sort [energy_use] of households with [dwelling_category = "vrijstaand"]
    set energy_use_free_low item (free / 4) energy_use_free
    set energy_use_free_high item (3 * free / 4) energy_use_free
  ]

  ask households
  [
    ;High Energy Quote
    ifelse fraction_income_to_energy >= 0.1
    [ set HEQ? true]
    [ set HEQ? false]
    ;Low Income High energy Costs
    if LI? = true
    [ if energy_expenses > mean_energy_expenses_0 ;issue: if many EQs go down, LIHC can increase. so, take only EQ at start of scenario
      [ set LIHC? true]
    ]
    ; Low Income Low Energetic Quality
    if LI? = true
    [ ifelse energy_label_num < 4
      [ set LILEQ? true
        ; if energy use is among the lowest 25% of the dwelling type: LILEQ-
        ; if energy use is among the highest 25% of the dwelling type: LILEQ+
        if dwelling_category = "meergezins"
        [ ifelse energy_use <= energy_use_apartments_low
          [ set LILEQ-? true ] [ set LILEQ-? false]
          ifelse energy_use >= energy_use_apartments_high
          [ set LILEQ+? true ] [ set LILEQ+? false]
        ]
        if dwelling_category = "rijwoning hoek"
        [ ifelse energy_use <= energy_use_row_corner_low
          [ set LILEQ-? true ] [ set LILEQ-? false]
          ifelse energy_use >= energy_use_row_corner_high
          [ set LILEQ+? true ] [ set LILEQ+? false]
        ]
        if dwelling_category = "rijwoning tussen"
        [ ifelse energy_use <= energy_use_rowhouse_low
          [ set LILEQ-? true ] [ set LILEQ-? false]
          ifelse energy_use >= energy_use_rowhouse_high
          [ set LILEQ+? true ] [ set LILEQ+? false]
        ]
        if dwelling_category = "vrijstaand"
        [ ifelse energy_use <= energy_use_free_low
          [ set LILEQ-? true ] [ set LILEQ-? false]
          ifelse energy_use >= energy_use_free_high
          [ set LILEQ+? true ] [ set LILEQ+? false]
        ]

      ]
      [ set LILEQ? false
        set LILEQ-? false
        set LILEQ+? false
      ]
    ]
    ; Low Energetic Quality & not able to improve sustainability
    if ownership = "owner"
    [ ifelse energy_label_num < 4
      [ ifelse LI? = true OR equity < 40000
        [ set oLEQ? true ]
        [ set oLEQ? false ]
      ]
      [ set oLEQ? false ]
    ]
    if ownership = "renter"
    [ ifelse energy_label_num < 4
      [ set rLEQ? true ]
      [ set rLEQ? false]
    ]
  ]

  set LEQ count households with [LEQ? = true] / total_households
  set HEQ count households with [HEQ? = true] / total_households
  set LIHC count households with [LIHC? = true] / total_households
  set LILEQ count households with [LILEQ? = true] / total_households
  set LILEQ- count households with [LILEQ-? = true] / total_households
  set LILEQ+ count households with [LILEQ+? = true] / total_households
  set oLEQ count households with [oLEQ? = true] / total_households
  set rLEQ count households with [rLEQ? = true] / total_households

  set mean_energy_label mean [energy_label_num] of households
  set mean_join count households with [building_connected? = true] / total_households
end

to update-lorenz-and-gini
  ;; Based on Wealth Distribution model by Uri Wilensky from NetLogo Model Library
  ;; this procedure recomputes the value of gini-index-reserve
  ;; and the points in lorenz-points for the Lorenz and Gini-Index plots
  let sorted-EQs sort [fraction_income_to_energy] of households
  let total-EQ sum sorted-EQs
  let EQ-sum-so-far 0
  let index 0
  set gini-index-reserve 0
  set lorenz-points []

  ;; now actually plot the Lorenz curve -- along the way, we also
  ;; calculate the Gini index.
  ;; (see the Info tab for a description of the curve and measure)
  repeat total_households [
    set EQ-sum-so-far (EQ-sum-so-far + item index sorted-EQs)
    set lorenz-points lput ((EQ-sum-so-far / total-EQ) * 100) lorenz-points
    set index (index + 1)
    set gini-index-reserve
      gini-index-reserve +
      (index / total_households) -
      (EQ-sum-so-far / total-EQ)
  ]
  set gini-EQ (gini-index-reserve / total_households) / 0.5

  ; do the same for income distribution
  let sorted-incomes sort [income] of households
  let total-income sum sorted-incomes
  let income-sum-so-far 0
  let index-income 0
  set gini-index-reserve-income 0
  set lorenz-points-income []
  repeat total_households [
    set income-sum-so-far (income-sum-so-far + item index-income sorted-incomes)
    set lorenz-points-income lput ((income-sum-so-far / total-income) * 100 ) lorenz-points-income
    set index-income index-income + 1
    set gini-index-reserve-income
      gini-index-reserve-income +
      (index-income / total_households) -
      (income-sum-so-far / total-income)
  ]
  set gini-income (gini-index-reserve-income / total_households) / 0.5

  ; do the same for energy expenses
  let sorted-ee sort [energy_expenses] of households
  let total-ee sum sorted-ee
  let ee-sum-so-far 0
  let index-ee 0
  set gini-index-reserve-ee 0
  set lorenz-points-ee []
  repeat total_households [
    set ee-sum-so-far (ee-sum-so-far + item index-ee sorted-ee)
    set lorenz-points-ee lput ((ee-sum-so-far / total-ee) * 100 ) lorenz-points-ee
    set index-ee index-ee + 1
    set gini-index-reserve-ee
      gini-index-reserve-ee +
      (index-ee / total_households) -
      (ee-sum-so-far / total-ee)
  ]
  set gini-ee (gini-index-reserve-ee / total_households) / 0.5


end

;________________________________________________________________________________________________________________________
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;     IMPLEMENTING HEATING SYSTEM    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to heat-network-implementation
  ; the heat network is built in three phases:
  ; first, corporation high-rises with collective heating system; (year 1)
  ; then homeowner high-rises with collective heating system; (year 2)
  ; then high-rises with individual heating system, individual homes of corporations and homeowners (year 3+)
  ask buildings
  [
    if building_connected? = false
    [
      let my_buildingid buildingid
      if ticks = 1
      [
        if owner = "corporation" AND nr_households > 1 ; first, connect corporation complexes
        [
          if heating_system = "collective" ; if the building has a collective heating system, no changes are needed, so no permission needed from renters
          [
            set building_connected? true
            set heating_system "heat network"
            ask households with [buildingid = my_buildingid]
            [
              set building_connected? true
            ]
          ]
        ]
      ]

      if heat_network_implementation = "open to all"
      [

        if ticks > 12 ; second, homeowner high-rises with collective heating system
        [
          if owner = "private" AND nr_households > 1
          [
            if heating_system = "collective"
            [
              if ( count households with [buildingid = my_buildingid AND choice = "heat network"]) / ( count households with [buildingid = my_buildingid]) > 0.5
              [ ;only proceed if more than half the homeowners in building agree
                set building_connected? true
                set heating_system "heat network"
                ask households with [buildingid = my_buildingid]
                [
                  set building_connected? true
                ]
              ]
            ]
          ]
        ]

        ; high-rise corporation with individual heating systems
        ; high-rise homeowners with individual heating systems

        if ticks > 24 ; third, connect individual homes (both corporations and homeowners may choose to connect)
        [
          if owner = "corporation" AND nr_households = 1 AND heating_system = "individual"
          [
            set building_connected? true
            set heating_system "heat network"
            ask households with [buildingid = my_buildingid]
            [
              set building_connected? true
            ]
          ]

          if owner = "private" AND nr_households = 1
          [
            let connect 0
            ask households with [buildingid = my_buildingid]
            [

              if choice = "heat network"
              [ set building_connected? true
                set connect 1
              ]
            ]

            if connect = 1
            [ set heating_system "heat network"
              set building_connected? true
            ]
          ]
        ]

      ]

    ]
  ]

  set fraction_connected count households with [building_connected? = true] / total_households
  set fraction_unaffordable count households with [unaffordable = true] / total_households
  set fraction_voucher count households with [voucher = true] / total_households
end

;________________________________________________________________________________________________________________________
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;     IMPROVING ENERGY LABEL    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to renovation
  ; in the renovation scenarios, thermal insulation will be applied to dwellings with energy labels G, F, E, D to label B
  ; starting with the buildings with the worst energy label.

  ask households with [energy_label_num <= 3]
  [
    if ticks = 12 * (1 + energy_label_num) ; every year, the next energy label (G, F, E, D) will be improved to B
    [
      ; first calculate extra expenses of the household
      if ownership = "renter"
      [
        let to-label 3
        ifelse floorspace < 70
        [ let from-label energy_label_num + 2
          set extra_expenses 12 * (item to-label item from-label rent-increase-dataset)
        ]
        [ ifelse floorspace <= 90
          [ let from-label energy_label_num + 12
            set extra_expenses 12 * (item to-label item from-label rent-increase-dataset)
          ]
          [ let from-label energy_label_num + 22
            set extra_expenses 12 * (item to-label item from-label rent-increase-dataset)
          ]
        ]
      ]
      if ownership = "owner"
      [
        set extra_expenses renovation_costs / 10 ; renovation costs spread over 10 years
      ]

      set energy_label_num 5
      set energy_label "B"
      set LEQ? false

      ; since the dwelling's energy efficiency has been improved, the expected energy demand needs to be recalculated
      calculate-energy-demand

    ]
  ]
end

to awareness-campaign
  if ticks = 12
  [
    ask households [set campaign_effect awareness_savings * susceptibility]
  ]
end

to final-reporters
  set mean_heat_use mean [heat_use] of households
  set mean_heat_expenses mean [heat_expenses] of households
  set mean_electricity_expenses mean [electricity_expenses] of households
  set energy_poverty (list LEQ HEQ LIHC LILEQ LILEQ- LILEQ+ oLEQ rLEQ)
  set ginis (list gini-ee gini-EQ gini-income)
  ; investigate the socio-economic groups that have energy poverty for each type of energy poverty
  let LEQs households with [LEQ? = true]
  let HEQs households with [HEQ? = true]
  let LIHCs households with [LIHC? = true]
  let LILEQs households with [LILEQ? = true]
  let LILEQ-s households with [LILEQ-? = true]
  let LILEQ+s households with [LILEQ+? = true]
  let oLEQs households with [oLEQ? = true]
  let rLEQs households with [rLEQ? = true]
  let EPs (list LEQs HEQs LIHCs LILEQs LILEQ-s LILEQ+s oLEQs rLEQs)

  ; of the groups with energy poverty, what are their characteristics?
  set fraction_renters_ep [] ; LEQ HEQ LIHC LILEQ LILEQ- LILEQ+ oLEQ rLEQ
  set mean_energy_use_ep []
  set mean_income_ep []
  set income_groups_ep []
  set household_type_ep []
  set dwelling_category_ep []
  set energy_labels_ep []

  foreach EPs [ x ->
    ifelse count x > 0
    [ set fraction_renters_ep lput (count x with [ownership = "renter"] / count x) fraction_renters_ep
      set mean_energy_use_ep lput (mean [energy_use] of x) mean_energy_use_ep
      set mean_income_ep lput (mean [income] of x) mean_income_ep

      ; calculate what fraction of households with this type of energy poverty are in each income group
      let income_groups_x table:to-list table:counts [income_group] of x ; counts of households with EP x in each income group
      let i 0 ; now need to replace each count by the fraction of EP x households
      foreach income_groups_x [ y ->
        set income_groups_x (replace-item i income_groups_x (replace-item 1 item i income_groups_x (item 1 item i income_groups_x / count x)))
        set i i + 1
      ]
      set income_groups_ep lput (sort-by [ [a b] -> first a < first b ] income_groups_x) income_groups_ep
      ;set income_groups_ep lput (sort-by [ [a b] -> first a < first b ] table:to-list table:counts [income_group] of x) income_groups_ep

      ; calculate household types
      let hh_x table:to-list table:counts [household_type] of x ; counts of households with EP x in each income group
      let j 0 ; now need to replace each count by the fraction of EP x households
      foreach hh_x [ y ->
        set hh_x (replace-item j hh_x (replace-item 1 item j hh_x (item 1 item j hh_x / count x)))
        set j j + 1
      ]
      set household_type_ep lput (sort-by [ [a b] -> first a < first b ] hh_x) household_type_ep
      ;set household_type_ep lput (sort-by [ [a b] -> first a < first b ] table:to-list table:counts [household_type] of x) household_type_ep

      ; calculate dwelling categories
      let dw_x table:to-list table:counts [dwelling_category] of x ; counts of households with EP x in each income group
      let k 0 ; now need to replace each count by the fraction of EP x households
      foreach dw_x [ y ->
        set dw_x (replace-item k dw_x (replace-item 1 item k dw_x (item 1 item k dw_x / count x)))
        set k k + 1
      ]
      set dwelling_category_ep lput (sort-by [ [a b] -> first a < first b ] dw_x) dwelling_category_ep
      ;set dwelling_category_ep lput (sort-by [ [a b] -> first a < first b ] table:to-list table:counts [dwelling_category] of x) dwelling_category_ep

      ; calculate dwelling categories
      let label_x table:to-list table:counts [energy_label] of x ; counts of households with EP x in each income group
      let l 0 ; now need to replace each count by the fraction of EP x households
      foreach label_x [ y ->
        set label_x (replace-item l label_x (replace-item 1 item l label_x (item 1 item l label_x / count x)))
        set l l + 1
      ]
      set energy_labels_ep lput (sort-by [ [a b] -> first a < first b ] label_x) energy_labels_ep
      ;set energy_labels_ep lput (sort-by [ [a b] -> first a < first b ] table:to-list table:counts [energy_label] of x) energy_labels_ep
    ]
    [ set fraction_renters_ep lput "" fraction_renters_ep
      set mean_energy_use_ep lput "" mean_energy_use_ep
      set mean_income_ep lput "" mean_income_ep
      set income_groups_ep lput "" income_groups_ep
      set household_type_ep lput "" household_type_ep
      set dwelling_category_ep lput "" dwelling_category_ep
      set energy_labels_ep lput "" energy_labels_ep
    ]
  ]

  ; what is the level of energy poverty within groups?
  set ep_homeownership []
  set ep_income_groups []
  set ep_household_types []
  set ep_dwelling_categories []
  set ep_energy_labels []
  let EP_levels (list ep_homeownership ep_income_groups ep_household_types ep_dwelling_categories ep_energy_labels)

  let owners households with [ownership = "owner"]
  let renters households with [ownership = "renter"]

  let income_groups_labels table:keys table:counts [income_group] of households
  set income_groups_labels sort-by [ [a b] -> first a < first b ] income_groups_labels

  foreach EPs [ x ->
    let ep_owners ""
    let ep_renters ""
    if count owners > 0
    [set ep_owners (count x with [ownership = "owner"] / count renters)]
    if count renters > 0
    [set ep_renters (count x with [ownership = "renter"] / count owners)]
    set ep_homeownership lput (list (list "owners" ep_owners) (list "renters" ep_renters)) ep_homeownership

    foreach income_groups_labels [ inc ->
      set ep_income_groups lput (list inc (count x with [income_group = inc] / count households with [income_group = inc])) ep_income_groups
    ]

    foreach household_labels [ hh ->
      set ep_household_types lput (list hh (count x with [household_type = hh] / count households with [household_type = hh])) ep_household_types
    ]

    foreach dwelling_labels [ cat ->
      set ep_dwelling_categories lput (list cat (count x with [dwelling_category = cat] / count households with [dwelling_category = cat])) ep_dwelling_categories
    ]

    foreach labels [ el ->
      ifelse count households with [energy_label = el] > 0
      [ set ep_energy_labels lput (list el (count x with [energy_label = el] / count households with [energy_label = el])) ep_energy_labels
      ]
      [ set ep_energy_labels lput (list el "") ep_energy_labels]
    ]
  ]




  ; now look at which groups have access to heat network
  let connected households with [building_connected? = true]
  let unconnected households with [building_connected? = false]
  let HN (list households connected unconnected)

  set fraction_renters_hn [] ; LEQ HEQ LIHC LILEQ LILEQ- LILEQ+ oLEQ rLEQ
  set mean_energy_use_hn []
  set mean_income_hn []
  set income_groups_hn []
  set household_type_hn []
  set dwelling_category_hn []
  set energy_labels_hn []

  foreach HN [ x ->
    ifelse count x > 0
    [
      set fraction_renters_hn lput (count x with [ownership = "renter"] / count x) fraction_renters_hn
      set mean_energy_use_hn lput (mean [energy_use] of x) mean_energy_use_hn
      set mean_income_hn lput (mean [income] of x) mean_income_hn

      ; calculate what fraction of households (connected and unconnected) are in each income group
      let income_groups_x table:to-list table:counts [income_group] of x ; counts of households (connected or unconnected) in each income group
      let i 0 ; now need to replace each count by the fraction of (connected or unconnected) households
      foreach income_groups_x [ y ->
        set income_groups_x (replace-item i income_groups_x (replace-item 1 item i income_groups_x (item 1 item i income_groups_x / count x)))
        set i i + 1
      ]
      set income_groups_hn lput (sort-by [ [a b] -> first a < first b ] income_groups_x) income_groups_hn
      ;set income_groups_hn lput (sort-by [ [a b] -> first a < first b ] table:to-list table:counts [income_group] of x) income_groups_ep

      ; calculate household types
      let hh_x table:to-list table:counts [household_type] of x ; counts of households with EP x in each income group
      let j 0 ; now need to replace each count by the fraction of EP x households
      foreach hh_x [ y ->
        set hh_x (replace-item j hh_x (replace-item 1 item j hh_x (item 1 item j hh_x / count x)))
        set j j + 1
      ]
      set household_type_hn lput (sort-by [ [a b] -> first a < first b ] hh_x) household_type_hn
      ;set household_type_hn lput (sort-by [ [a b] -> first a < first b ] table:to-list table:counts [household_type] of x) household_type_ep

      ; calculate dwelling categories
      let dw_x table:to-list table:counts [dwelling_category] of x ; counts of households with EP x in each income group
      let k 0 ; now need to replace each count by the fraction of EP x households
      foreach dw_x [ y ->
        set dw_x (replace-item k dw_x (replace-item 1 item k dw_x (item 1 item k dw_x / count x)))
        set k k + 1
      ]
      set dwelling_category_hn lput (sort-by [ [a b] -> first a < first b ] dw_x) dwelling_category_hn
      ;set dwelling_category_hn lput (sort-by [ [a b] -> first a < first b ] table:to-list table:counts [dwelling_category] of x) dwelling_category_ep

      ; calculate dwelling categories
      let label_x table:to-list table:counts [energy_label] of x ; counts of households with EP x in each income group
      let l 0 ; now need to replace each count by the fraction of EP x households
      foreach label_x [ y ->
        set label_x (replace-item l label_x (replace-item 1 item l label_x (item 1 item l label_x / count x)))
        set l l + 1
      ]
      set energy_labels_hn lput (sort-by [ [a b] -> first a < first b ] label_x) energy_labels_hn
      ;set energy_labels_hn lput (sort-by [ [a b] -> first a < first b ] table:to-list table:counts [energy_label] of x) energy_labels_ep
    ]
    [ set fraction_renters_hn lput "" fraction_renters_hn
      set mean_energy_use_hn lput "" mean_energy_use_hn
      set mean_income_hn lput "" mean_income_hn
      set income_groups_hn lput "" income_groups_hn
      set household_type_hn lput "" household_type_hn
      set dwelling_category_hn lput "" dwelling_category_hn
      set energy_labels_hn lput "" energy_labels_hn
    ]
  ]
end


;________________________________________________________________________________________________________________________
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;     UPDATING THE MAP     ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to update-view
  update-map
end

to update-map
  ; redraw buildings (based on current map mode)


  if show-building-feature = "nr of dwellings"
  [
    clear-drawing
    foreach gis:feature-list-of building-dataset [ feature ->
      let gebr gis:property-value feature "gebr_woonf"
      ifelse gebr > 1
      [gis:set-drawing-color green
        gis:draw feature 1]
      [gis:set-drawing-color grey
        gis:draw feature 1]
    ]
  ]

  if show-building-feature = "heat network connection"
  [
    if total_households > 0
    [
      clear-drawing
      foreach gis:feature-list-of building-dataset [ feature ->
        let location gis:location-of gis:centroid-of feature
        let connected? one-of [building_connected?] of buildings with [xcor = item 0 location AND ycor = item 1 location]
        ifelse connected?
        [
          gis:set-drawing-color green
          gis:draw feature 1
        ]
        [
          gis:set-drawing-color red
          gis:draw feature 1
        ]
      ]
    ]
  ]

  if show-building-feature = "heating system"
  [
    if total_households > 0
    [
      clear-drawing
      foreach gis:feature-list-of building-dataset [ feature ->
        let location gis:location-of gis:centroid-of feature
        let system one-of [heating_system] of buildings with [xcor = item 0 location AND ycor = item 1 location]
        if system = "individual"
        [
          gis:set-drawing-color red
          gis:draw feature 1
        ]
        if system = "collective"
        [
          gis:set-drawing-color yellow
          gis:draw feature 1
        ]
        if system = "heat network"
        [
          gis:set-drawing-color green
          gis:draw feature 1
        ]
      ]
    ]
  ]

  if show-building-feature = "construction year"
  [
    clear-drawing
    foreach gis:feature-list-of building-dataset [ feature ->
      let location gis:location-of gis:centroid-of feature
      let year gis:property-value feature "bouwjaar"
      ifelse year < 1930
      [ gis:set-drawing-color green ]
      [ ifelse year < 1946
        [ gis:set-drawing-color red ]
        [ ifelse year < 1965
          [ gis:set-drawing-color orange ]
          [ ifelse year < 1975
            [ gis:set-drawing-color brown ]
            [ ifelse year < 1992
              [ gis:set-drawing-color yellow ]
              [ ifelse year < 1997
                [ gis:set-drawing-color green ]
                [ ifelse year < 2000
                  [ gis:set-drawing-color lime ]
                  [ ifelse year < 2006
                    [ gis:set-drawing-color turquoise ]
                    [ ifelse year < 2011
                      [ gis:set-drawing-color cyan ]
                      [ ifelse year < 2015
                        [ gis:set-drawing-color sky ]
                        [ ifelse year > 2014
                          [ gis:set-drawing-color violet ]
                          [ gis:set-drawing-color gray]
                        ]
                      ]
                    ]
                  ]
                ]
              ]
            ]
          ]
        ]
      ]

      gis:draw feature 1

      ]
  ]

  if show-building-feature = "ownership"
  [
    clear-drawing
    if total_households > 0
    [
      clear-drawing
      foreach gis:feature-list-of building-dataset [ feature ->
        let location gis:location-of gis:centroid-of feature
        let owners one-of [owner] of buildings with [xcor = item 0 location AND ycor = item 1 location]
        if owners = "corporation"
        [
          gis:set-drawing-color red
          gis:draw feature 1
        ]
        if owners = "private"
        [
          gis:set-drawing-color green
          gis:draw feature 1
        ]
      ]
    ]
  ]


  ; update agent colours
  ask households
  [
    if show-household-feature = "energy label"
    [
      ifelse energy_label_num = 999
      [set color 5]
      [set color 15 + 10 * energy_label_num] ; gradient color will depend on energy label
    ]

    if show-household-feature = "initial energy label"
    [
      ifelse energy_label_initial = "A++++" OR energy_label_initial = "A+++" OR energy_label_initial = "A++" OR energy_label_initial = "A+" OR energy_label_initial = "A"
      [ set color turquoise ]
      [ ifelse energy_label_initial = "B"
        [ set color lime ]
        [ ifelse energy_label_initial = "C"
          [ set color green ]
          [ ifelse energy_label_initial = "D"
            [ set color yellow ]
            [ ifelse energy_label_initial = "E"
              [ set color brown ]
              [ ifelse energy_label_initial = "F"
                [ set color orange ]
                [ ifelse energy_label_initial = "G"
                  [ set color red ]
                  [ set color gray ] ; if no energy label is known
                ]
              ]
            ]
          ]
        ]
      ]
    ]

    if show-household-feature = "income"
    [
      set color 120 + income
    ]

    if show-household-feature = "ownership"
    [
      if ownership = "renter" [ set color red ]
      if ownership = "owner" [ set color green ]
    ]

    if show-household-feature = "fraction income to energy"
    [
      let c 55 - 20 * (round (10 * fraction_income_to_energy))
      ifelse c > 15
      [ set color 55 - 20 * (round (10 * fraction_income_to_energy))]
      [ set color red ]
    ]

    if show-household-feature = "HEQ"
    [
      ifelse fraction_income_to_energy > 0.1
      [ set color red ] ; hh with energy poverty
      [ ifelse fraction_income_to_energy_exp > 0.1
        [ set color yellow ] ; hh with hidden energy poverty
        [ set color green ]  ; hh with no energy poverty
      ]
    ]

    if show-household-feature = "LIHC"
    [
      ifelse LIHC? = true
      [ set color red ]
      [ set color green ]
    ]

    if show-household-feature = "LILEQ"
    [
      ifelse LILEQ? = true
      [ set color red ]
      [ set color green ]
    ]

    if show-household-feature = "oLEQ & rLEQ"
    [
      ifelse oLEQ? = true
      [ set color yellow ]
      [ ifelse rLEQ? = true
        [ set color red ]
        [ set color green ]
      ]
    ]

    if show-household-feature = "decision strategy"
    [
      ifelse strategy = 0
      [ set color gray ]
      [ if strategy = "repetition" [ set color red ]
        if strategy = "deliberation" [ set color green ]
        if strategy = "social comparison" [ set color yellow ]
        if strategy = "imitation" [ set color blue ]
        if strategy = "coin flip" [ set color magenta ]
      ]
    ]

    if show-household-feature = "choice"
    [ ifelse choice = "heat network"
      [ set color green ]
      [ ifelse choice = "no heat network"
        [ set color red ]
        [ set color gray ]
      ]
    ]
  ]
end

;________________________________________________________________________________________________________________________
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;     PLOTTING     ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to plots-setup
  set counts table:counts [ energy_label ] of households
  set labels sort table:keys counts
  set n length labels
  set dwelling_counts table:counts [ dwelling_category ] of households
  set dwelling_labels sort table:keys dwelling_counts
  set dwelling_n length dwelling_labels
  set rvo_counts table:counts [ energy_label_initial ] of households
  set rvo_labels sort table:keys rvo_counts
  set rvo_n length rvo_labels
  set proxy_counts table:counts [ energy_label_proxy ] of households with [ energy_label_initial = "" ]
  set proxy_labels sort table:keys proxy_counts
  set proxy_n length proxy_labels
  set household_counts table:counts [ household_type ] of households
  set household_labels sort table:keys household_counts
  set household_n length household_labels
  set age_counts table:counts [bouwjaar] of households
  set age_labels sort table:keys age_counts
  set age_n length age_labels
  set income_counts table:counts [ income_group] of households
  set income_labels sort table:keys income_counts
  set income_n length income_groups


  ; plotting age distribution by age category instead of by year
  let ages table:make
  let pre-thirty count households with [bouwjaar < 1930]
  if pre-thirty > 0 [table:put ages "<1930" pre-thirty]
  let thirties count households with [bouwjaar >= 1930 AND bouwjaar < 1946]
  if thirties > 0 [table:put ages "1930-1945" thirties]
  let fifties count households with [bouwjaar >= 1946 AND bouwjaar < 1965]
  if fifties > 0 [table:put ages "1946-1964" fifties]
  let sixties count households with [bouwjaar >= 1965 AND bouwjaar < 1975]
  if sixties > 0 [table:put ages "1965-1974" sixties]
  let eighties count households with [bouwjaar >= 1975 AND bouwjaar < 1992]
  if eighties > 0 [table:put ages "1975-1991" eighties]
  let nine-two count households with [bouwjaar >= 1992 AND bouwjaar < 1996]
  if nine-two > 0 [table:put ages "1992-1995" nine-two]
  let nine-six count households with [bouwjaar >= 1996 AND bouwjaar < 2000]
  if nine-six > 0 [table:put ages "1996-1999" nine-six]
  let two-k count households with [bouwjaar >= 2000 AND bouwjaar < 2006]
  if two-k > 0 [table:put ages "2000-2005" two-k]
  let two-k6 count households with [bouwjaar >= 2006 AND bouwjaar < 2011]
  if two-k6 > 0 [table:put ages "2006-2010" two-k6]
  let two-k11 count households with [bouwjaar >= 2011 AND bouwjaar < 2015]
  if two-k11 > 0 [table:put ages "2011-2014" two-k11]
  let two-k15 count households with [bouwjaar >= 2015]
  if two-k15 > 0 [table:put ages ">=2015" two-k15]
  set age_category_counts ages
  set age_category_labels table:keys ages
  set age_category_n length age_category_labels
end

to plot-energy-labels
  set-current-plot "Energy labels"
  clear-plot
  set-plot-x-range 0 n
  set-plot-y-range 0 max table:values counts
  let step 1 ; tweak this to leave no gaps
  (foreach labels range n [ [s i] ->
    let y table:get counts s
    let c 5 + 10 * (n - i)
    create-temporary-plot-pen s
    set-plot-pen-color c
    set-plot-pen-mode 1 ; bar mode
    foreach (range 0 y step) [ _y -> plotxy i _y ]
    set-plot-pen-color black
    plotxy i y
    set-plot-pen-color c ; to get the right color in the legend
  ])
end

to plot-energy-labels-rvo
  set-plot-x-range 0 rvo_n
  set-plot-y-range 0 max table:values counts
  let step 1 ; tweak this to leave no gaps
  (foreach rvo_labels range rvo_n [ [s i] ->
    let y table:get rvo_counts s
    let c 5 + 10 * (n - i + 1)

    ifelse s = ""
    [ create-temporary-plot-pen "N/A"
      set-plot-pen-color gray
    ]
    [ create-temporary-plot-pen s
      set-plot-pen-color c
    ]
    set-plot-pen-mode 1 ; bar mode
    foreach (range 0 y step) [ _y -> plotxy i _y ]
    set-plot-pen-color black
    plotxy i y
    ifelse s = ""
    [set-plot-pen-color gray]
    [set-plot-pen-color c] ; to get the right color in the legend
  ])
end

to plot-energy-labels-proxy
  set-current-plot "Proxy energy labels"
  clear-plot
  set-plot-x-range 0 proxy_n
  set-plot-y-range 0 max table:values counts
  let step 0.1 ; tweak this to leave no gaps
  (foreach proxy_labels range proxy_n [ [s i] ->
    let y table:get proxy_counts s
    let c 5 + 10 * (proxy_n - i)
    create-temporary-plot-pen s
    set-plot-pen-color c
    set-plot-pen-mode 1 ; bar mode
    foreach (range 0 y step) [ _y -> plotxy i _y ]
    set-plot-pen-color black
    plotxy i y
    set-plot-pen-color c ; to get the right color in the legend
  ])
end

to plot-floorspace
  set-current-plot "Floorspace"
  (foreach labels range n [ [s i] ->
    let c 5 + 10 * (n - i)

    create-temporary-plot-pen s
    set-plot-pen-mode 0 ; line mode
    set-plot-pen-color c
    if count households with [energy_label = s] > 0
    [ plot mean [floorspace] of households with [energy_label = s] ]
  ])
end

to plot-income-labels
  set-current-plot "Income per label"
  (foreach labels range n [ [s i] ->
    let c 5 + 10 * (n - i)

    if count households with [energy_label = s] > 0
    [ create-temporary-plot-pen s
      set-plot-pen-mode 0 ; line mode
      set-plot-pen-color c
      plot mean [income] of households with [energy_label = s] ]
  ])
end

to plot-income-per-ownership
  set-current-plot "Income per ownership"
  (foreach ["owner" "renter"] [ x ->
    create-temporary-plot-pen x
    if x = "owner" [ set-plot-pen-color green ]
    if x = "renter" [ set-plot-pen-color red ]
    plot mean [income] of households with [ownership = x]
  ])
end

to plot-energy-price-labels
  set-current-plot "Energy price per label"
  (foreach labels range n [ [s i] ->
    let c 5 + 10 * (n - i)

    if count households with [energy_label = s] > 0
    [ create-temporary-plot-pen s
      set-plot-pen-mode 0 ; line mode
      set-plot-pen-color c
      plot mean [energy_price] of households with [energy_label = s] ]
  ])
end

to plot-heat-expense-labels
  set-current-plot "Heat expense per label"
  (foreach labels range n [ [s i] ->
    let c 5 + 10 * (n - i)

    if count households with [energy_label = s] > 0
    [ create-temporary-plot-pen s
      set-plot-pen-mode 0 ; line mode
      set-plot-pen-color c
      plot mean [heat_expenses] of households with [energy_label = s] ]
  ])
end

to plot-energy-expense-labels
  set-current-plot "Energy expense per label"
  (foreach labels range n [ [s i] ->
    let c 5 + 10 * (n - i)

    if count households with [energy_label = s] > 0
    [ create-temporary-plot-pen s
      set-plot-pen-mode 0 ; line mode
      set-plot-pen-color c
      plot mean [energy_expenses] of households with [energy_label = s] ]
  ])
end

to plot-energy-expense-incomes
  set-current-plot "Energy expense per income group"
  (foreach income_labels range income_n [ [s i] ->
    let c 115 - 10 * (income_n - i)

    if count households with [income_group = s] > 0
    [ create-temporary-plot-pen s
      set-plot-pen-mode 0 ; line mode
      set-plot-pen-color c
      plot mean [energy_expenses] of households with [income_group = s] ]
  ])
end

to plot-energy-quote-incomes
  set-current-plot "Energy quote per income group"
  (foreach income_labels range income_n [ [s i] ->
    let c 115 - 10 * (income_n - i)

    if count households with [income_group = s] > 0
    [ create-temporary-plot-pen s
      set-plot-pen-mode 0 ; line mode
      set-plot-pen-color c
      plot mean [fraction_income_to_energy] of households with [income_group = s] ]
  ])
end

to plot-energy-expense-ownership
  set-current-plot "Energy expense per ownership"
  (foreach ["owner" "renter"] range 2 [ [s i] ->
    let c 5 + 50 * (2 + i)

    if count households with [ownership = s] > 0
    [ create-temporary-plot-pen s
      set-plot-pen-mode 0 ; line mode
      set-plot-pen-color c
      plot mean [energy_expenses] of households with [ownership = s] ]
  ])
end

to plot-income-to-heat-labels
  set-current-plot "Income to heat per label"
  ;set-plot-y-range 0 max [fraction_income_to_heat] of households
  (foreach labels range n [ [s i] ->
    let c 5 + 10 * (n - i)

    if count households with [energy_label = s] > 0
    [ create-temporary-plot-pen s
      set-plot-pen-mode 0 ; line mode
      set-plot-pen-color c
      plot mean [fraction_income_to_heat] of households with [energy_label = s] ]
  ])
end

to plot-income-to-energy-labels
  set-current-plot "Income to energy per label"
  ;set-plot-y-range 0 max [fraction_income_to_energy] of households
  (foreach labels range n [ [s i] ->
    let c 5 + 10 * (n - i)

    if count households with [energy_label = s] > 0
    [ create-temporary-plot-pen s
      set-plot-pen-mode 0 ; line mode
      set-plot-pen-color c
      plot mean [fraction_income_to_energy] of households with [energy_label = s] ]
  ])
end

to plot-income-to-heat
  set-current-plot "Income to heat"
  set-histogram-num-bars 40
  set-plot-pen-mode 1 ; histogram mode
  set-plot-x-range 0 1
  histogram [fraction_income_to_heat] of households
end

to plot-income-to-energy
  set-current-plot "Income to energy"
  set-histogram-num-bars 40
  set-plot-pen-mode 1 ; histogram mode
  set-plot-x-range 0 1
  histogram [fraction_income_to_energy] of households
end

to plot-income-distribution
  set-current-plot "Income distribution"
  set-histogram-num-bars (ceiling (max [income] of households / 2000)) - (floor (min [income] of households / 2000)) ; make sure each bar represents a range of incomes of 2000€ (-2000-0, 0-2000, 2000-4000, etc)
  set-plot-pen-mode 1 ; histogram mode
  set-plot-x-range 2000 * (floor (min [income] of households / 2000)) 2000 * (ceiling (max [income] of households / 2000))
  histogram [income] of households
end


to plot-heat-demand-labels
  set-current-plot "Heat demand per label"
  (foreach labels range n [ [s i] ->
    let c 5 + 10 * (n - i)

    if count households with [energy_label = s] > 0
    [ create-temporary-plot-pen s
      set-plot-pen-mode 0 ; line mode
      set-plot-pen-color c
      plot mean [heat_demand] of households with [energy_label = s] ]
  ])
end


to plot-energy-demand-labels
  set-current-plot "Energy demand per label"
  (foreach labels range n [ [s i] ->
    let c 5 + 10 * (n - i)

    if count households with [energy_label = s] > 0
    [ create-temporary-plot-pen s
      set-plot-pen-mode 0 ; line mode
      set-plot-pen-color c
      plot mean [energy_demand] of households with [energy_label = s] ]
  ])
end

;to plot-heat-use-labels
;  set-current-plot "Heat use per label"
;  (foreach labels range n [ [s i] ->
;    let c 5 + 10 * (n - i)
;    create-temporary-plot-pen s
;    set-plot-pen-mode 0 ; line mode
;    set-plot-pen-color c
;    plot mean [heat_use] of households with [energy_label = s]
;    create-temporary-plot-pen word s "_t"
;    set-plot-pen-mode 2 ; dot mode
;    set-plot-pen-color c
;    plot mean [heat_demand] of households with [energy_label = s]
;  ])
;end

to plot-heat-use-labels
  set-current-plot "Heat use per label"
  (foreach labels range n [ [s i] ->
    let c 5 + 10 * (n - i)

    if count households with [energy_label = s] > 0
    [ create-temporary-plot-pen s
      set-plot-pen-mode 0 ; line mode
      set-plot-pen-color c
      plot mean [heat_use] of households with [energy_label = s] ]
  ])
end

to plot-energy-use-labels
  set-current-plot "Energy use per label"
  (foreach labels range n [ [s i ] ->
    let c 5 + 10 * (n - i)

    if count households with [energy_label = s] > 0
    [ create-temporary-plot-pen s
      set-plot-pen-mode 0 ; line mode
      set-plot-pen-color c
      plot mean [energy_use] of households with [energy_label = s] ]
  ])
end

to plot-energy-to-heat-labels
  set-current-plot "Energy to heat per label"
  (foreach labels range n [ [s i] ->
    let c 5 + 10 * (n - i)

    if count households with [energy_label = s] > 0
    [ create-temporary-plot-pen s
      set-plot-pen-mode 0 ; line mode
      set-plot-pen-color c
      plot mean [fraction_energy_to_heat] of households with [energy_label = s] ]
  ])
end

to plot-energy-poverty
  set-current-plot "Energy poverty indicators"
  ; HEQ, LIHC, LILEQ, LILEQ+, LILEQ-, oLEQ, rLEQ
  set-plot-pen-mode 0
  set-plot-pen-color red
  plot HEQ
  set-plot-pen-color orange
  plot LIHC
  set-plot-pen-color sky
  plot LILEQ
  set-plot-pen-color cyan
  plot LILEQ-
  set-plot-pen-color blue
  plot LILEQ+
  set-plot-pen-color green
  plot oLEQ
  set-plot-pen-color lime
  plot rLEQ

end

to plot-dwelling-types
  set-current-plot "Dwelling types"
  clear-plot
  set-plot-x-range 0 dwelling_n
  set-plot-y-range 0 max table:values dwelling_counts
  let step 0.1 ; tweak this to leave no gaps
  (foreach dwelling_labels range dwelling_n [ [s i] ->
    let y table:get dwelling_counts s
    let c 135 - 10 * (dwelling_n - i)
    create-temporary-plot-pen s
    set-plot-pen-color c
    set-plot-pen-mode 1 ; bar mode
    foreach (range 0 y step) [ _y -> plotxy i _y ]
    set-plot-pen-color black
    plotxy i y
    set-plot-pen-color c ; to get the right color in the legend
  ])
end

to plot-household-types
  set-current-plot "Household types"
  clear-plot
  set-plot-x-range 0 household_n
  set-plot-y-range 0 max table:values household_counts
  let step 1
  (foreach household_labels range household_n [ [s i ] ->
    let y table:get household_counts s
    let c 135 - 10 * (household_n - i)
    create-temporary-plot-pen s
    set-plot-pen-color c
    set-plot-pen-mode 1 ; bar mode
    foreach (range 0 y step) [ _y -> plotxy i _y ]
    set-plot-pen-color black
    plotxy i y
    set-plot-pen-color c ; to get the right color in the legend
  ])
end

to plot-building-age
  set-current-plot "Building age distribution"
  clear-plot
  set-plot-x-range 0 age_n
  set-plot-y-range 0 max table:values age_counts
  let step 1
  (foreach age_labels range age_n [ [s i ] ->
    let y table:get age_counts s
    let c 135 - 10 * (age_n - i)
    create-temporary-plot-pen (word s)
    set-plot-pen-color c
    set-plot-pen-mode 1 ; bar mode
    foreach (range 0 y step) [ _y -> plotxy i _y ]
    set-plot-pen-color black
    plotxy i y
    set-plot-pen-color c ; to get the right color in the legend
  ])
end

to plot-building-age-categories
  set-current-plot "Building ages"
  clear-plot
  set-plot-x-range 0 age_category_n
  set-plot-y-range 0 max table:values age_category_counts
  let step 1
  (foreach age_category_labels range age_category_n [ [s i ] ->
    let y table:get age_category_counts s
    let c 135 - 10 * (age_n - i)
    create-temporary-plot-pen (word s)
    set-plot-pen-color c
    set-plot-pen-mode 1 ; bar mode
    foreach (range 0 y step) [ _y -> plotxy i _y ]
    set-plot-pen-color black
    plotxy i y
    set-plot-pen-color c ; to get the right color in the legend
  ])
end
@#$#@#$#@
GRAPHICS-WINDOW
215
10
719
515
-1
-1
15.030303030303031
1
10
1
1
1
0
0
0
1
-16
16
-16
16
1
1
1
ticks
30.0

BUTTON
4
129
104
162
NIL
setup-model
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
4
92
104
125
NIL
setup-map
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
120
535
320
580
buurt
buurt
"buitenhof_noord" "gillisbuurt" "het_rode_dorp" "multatulibuurt" "roland_holstbuurt" "wijk_24_voorhof" "wijk_25_buitenhof"
5

CHOOSER
5
330
195
375
show-household-feature
show-household-feature
"energy label" "initial energy label" "income" "ownership" "fraction income to energy" "HEQ" "LIHC" "LILEQ" "oLEQ & rLEQ" "decision strategy" "choice"
5

BUTTON
117
92
195
125
go once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
5
285
195
330
show-building-feature
show-building-feature
"heat network connection" "nr of dwellings" "heating system" "construction year" "ownership"
4

TEXTBOX
5
515
155
533
Scenario settings
14
0.0
1

BUTTON
117
129
195
162
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
10
200
160
218
Map view settings
14
0.0
1

TEXTBOX
7
10
193
112
Model initialization
14
0.0
1

TEXTBOX
7
31
157
87
1) Choose scenario settings\n2) Setup map\n3) Setup model\n4) Go
11
0.0
1

TEXTBOX
5
380
134
431
Legend (expand)
14
15.0
1

TEXTBOX
6
397
127
453
BUILDINGS\nnr of dwellings\nheat network connection\nheating system
11
0.0
1

TEXTBOX
7
456
77
523
HOUSEHOLDS\nenergy label\nincome\nownership
11
0.0
1

TEXTBOX
136
470
151
488
G
11
15.0
1

TEXTBOX
154
470
169
488
A
11
75.0
1

TEXTBOX
135
498
169
516
renter
11
15.0
1

TEXTBOX
170
498
210
516
owner
11
55.0
1

TEXTBOX
136
485
155
503
low
11
0.0
1

TEXTBOX
159
485
184
503
high
11
128.0
1

TEXTBOX
153
411
170
429
>1
11
55.0
1

TEXTBOX
136
425
151
443
No
11
15.0
1

TEXTBOX
153
425
173
443
Yes
11
55.0
1

TEXTBOX
137
411
152
429
1
11
5.0
1

PLOT
1505
650
1760
800
Household characteristics
NIL
NIL
0.0
60.0
0.0
1.0
true
true
"" ""
PENS
"mean join" 1.0 0 -16777216 true "" "if update-plots? = true [plot mean_join]"
"mean energy label" 1.0 0 -2674135 true "" "if update-plots? = true [plot mean_energy_label / 10]"

PLOT
1225
340
1505
490
Heating system
Month
Count
0.0
60.0
0.0
10.0
true
true
"" ""
PENS
"Collective heating" 1.0 0 -7500403 true "" "if update-plots? = true [plot count households with [heating_system = \"collective\"]]"
"Individual heating" 1.0 0 -2674135 true "" "if update-plots? = true [plot count households with [heating_system = \"individual\"]]"
"Heat network" 1.0 0 -16777216 true "" "if update-plots? = true [plot count households with [building_connected? = true]]"

TEXTBOX
5
166
197
207
NB: if model is slow, set speed to 'faster' and view updates 'on ticks'
11
15.0
1

SLIDER
520
535
700
568
share_collective_system
share_collective_system
0
1
0.8
0.05
1
NIL
HORIZONTAL

TEXTBOX
83
439
131
457
individual
11
15.0
1

TEXTBOX
130
439
176
457
collective
11
44.0
1

TEXTBOX
176
439
220
457
network
11
55.0
1

MONITOR
1255
575
1395
620
% part of heat network
count households with [building_connected?] / total_households * 100
1
1
11

CHOOSER
120
625
320
670
financial_intervention
financial_intervention
"none" "energy tax" "vouchers" "energy tax and vouchers"
0

PLOT
725
205
925
340
Income to heat
Fraction
Count
0.0
1.0
0.0
1.0
true
false
"" "if update-plots? = true [plot-income-to-heat]"
PENS
"pen-0" 1.0 0 -16777216 true "" ""

MONITOR
1630
340
1710
385
Households
total_households
17
1
11

MONITOR
1710
340
1790
385
Proxy labels
total_proxy_labels
17
1
11

PLOT
725
490
925
640
Income to heat per label
Month
Fraction
0.0
60.0
0.0
0.1
true
true
"" "if update-plots? = true [plot-income-to-heat-labels]"
PENS

PLOT
725
790
925
940
Heat expense per label
Month
Expense (€/y)
0.0
60.0
0.0
10.0
true
true
"" "if update-plots? = true [plot-heat-expense-labels]"
PENS

PLOT
1225
205
1455
340
Dwelling types
NIL
Count
0.0
10.0
0.0
10.0
true
true
"plot-dwelling-types" ""
PENS

PLOT
1385
490
1560
650
Energy labels RVO
NIL
NIL
0.0
10.0
0.0
10.0
false
true
"plot-energy-labels-rvo" ""
PENS

PLOT
1225
650
1505
800
Floorspace
Month
Area (m2)
0.0
60.0
0.0
10.0
true
true
"" "if update-plots? = true [plot-floorspace]"
PENS

PLOT
1225
490
1385
650
Energy labels
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"plot-energy-labels" "plot-energy-labels"
PENS

PLOT
1545
490
1720
650
Proxy energy labels
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"plot-energy-labels-proxy\n" ""
PENS

MONITOR
1630
385
1710
430
% Renter
count households with [ownership = \"renter\"] / total_households * 100
1
1
11

PLOT
725
940
925
1090
Heat demand per label
month
GJ
0.0
60.0
0.0
10.0
true
true
"" "if update-plots? = true [plot-heat-demand-labels]"
PENS

PLOT
725
640
925
790
Heat use per label
Month
GJ
0.0
60.0
0.0
10.0
true
true
"" "if update-plots? = true [plot-heat-use-labels]"
PENS

PLOT
1455
30
1710
205
Household types
NIL
Count
0.0
10.0
0.0
10.0
true
true
"plot-household-types" ""
PENS

PLOT
1455
205
1630
340
Income distribution
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"plot-income-distribution\nplot-income-distribution" ""
PENS
"default" 1.0 0 -16777216 true "" ""

MONITOR
1630
205
1710
250
Mean income
mean [income] of households
0
1
11

SLIDER
345
570
515
603
threshold-use
threshold-use
0
50
35.0
1
1
GJ/y
HORIZONTAL

SLIDER
345
535
515
568
heat-cost-relative-to-max
heat-cost-relative-to-max
0
1
0.92
0.01
1
NIL
HORIZONTAL

MONITOR
1630
250
1710
295
Renter income
mean [income] of households with [ownership = \"renter\"]
0
1
11

MONITOR
1630
295
1710
340
Owner income
mean [income] of households with [ownership = \"owner\"]
0
1
11

PLOT
1455
340
1630
490
Income per label
Month
Income (€/y)
0.0
10.0
0.0
10.0
true
true
"" "if update-plots? = true [plot-income-labels]"
PENS

PLOT
925
205
1205
340
Income to energy
Fraction
Count
0.0
1.0
0.0
10.0
true
false
"" "if update-plots? = true [plot-income-to-energy]"
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
925
490
1205
640
Income to energy per label
Month
Fraction
0.0
60.0
0.0
0.1
true
true
"" "if update-plots? = true [plot-income-to-energy-labels]\n"
PENS

PLOT
925
790
1205
940
Energy expense per label
Month
Expense (€/y)
0.0
60.0
0.0
10.0
true
true
"" "if update-plots? = true [plot-energy-expense-labels]"
PENS

PLOT
725
30
925
205
Energy to heat per label
NIL
NIL
0.0
60.0
0.0
1.0
true
true
"" "if update-plots? = true [plot-energy-to-heat-labels]\n"
PENS

MONITOR
1365
935
1505
980
Mean energy use [GJ]
mean_energy_use
1
1
11

MONITOR
1365
890
1505
935
Mean energy demand [GJ]
mean [energy_demand] of households
1
1
11

TEXTBOX
1225
10
1375
28
Building characteristics
14
0.0
1

TEXTBOX
1460
10
1640
41
Household characteristics
14
0.0
1

TEXTBOX
725
10
875
28
Energy metrics
14
0.0
1

TEXTBOX
350
515
500
533
Parameters
14
0.0
1

MONITOR
1225
800
1365
845
% income to energy
mean [fraction_income_to_energy] of households * 100
1
1
11

MONITOR
1225
845
1365
890
% HEQ
count households with [fraction_income_to_energy >= 0.1] / total_households * 100
1
1
11

PLOT
925
640
1205
790
Energy use per label
Month
GJ
0.0
60.0
0.0
10.0
true
true
"" "if update-plots? = true [plot-energy-use-labels]"
PENS

MONITOR
1365
800
1505
845
Mean heat demand [GJ]
mean [heat_demand] of households
1
1
11

MONITOR
1365
845
1505
890
Mean heat use [GJ]
mean [heat_use] of households
1
1
11

PLOT
1225
30
1455
205
Building ages
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"plot-building-age-categories" ""
PENS

PLOT
925
30
1205
205
Energy poverty indicators
Month
Fraction
0.0
60.0
0.0
0.6
true
true
"" ";plot-energy-poverty"
PENS
"HEQ" 1.0 0 -2674135 true "" "if update-plots? = true [plot HEQ]"
"LIHC" 1.0 0 -955883 true "" "if update-plots? = true [plot LIHC]"
"LILEQ" 1.0 0 -13791810 true "" "if update-plots? = true [plot LILEQ]"
"LILEQ-" 1.0 0 -11221820 true "" "if update-plots? = true [plot LILEQ-]"
"LILEQ+" 1.0 0 -13345367 true "" "if update-plots? = true [plot LILEQ+]"
"oLEQ" 1.0 0 -10899396 true "" "if update-plots? = true [plot oLEQ]"
"rLEQ" 1.0 0 -13840069 true "" "if update-plots? = true [plot rLEQ]"
"LI" 1.0 0 -7500403 true "" "if update-plots? = true [plot LI]"
"LEQ" 1.0 0 -16777216 true "" "if update-plots? = true [plot LEQ]"

MONITOR
1710
205
1790
250
Mean equity
mean [equity] of households
0
1
11

MONITOR
1710
250
1790
295
Renter equity
mean [equity] of households with [ownership = \"renter\"]
0
1
11

MONITOR
1710
295
1790
340
Owner equity
mean [equity] of households with [ownership = \"owner\"]
0
1
11

PLOT
5
830
205
980
Lorenz curve EQ
NIL
NIL
0.0
100.0
0.0
100.0
false
true
"" ""
PENS
"lorenz" 1.0 0 -2674135 true "" "plot-pen-reset\nset-plot-pen-interval 100 / total_households\nplot 0\nforeach lorenz-points plot"
"equal" 100.0 0 -16777216 true "plot 0\nplot 100" ""

PLOT
205
830
405
980
Gini Index EQ
Month
Gini
0.0
50.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -13345367 true "" "plot (gini-index-reserve / total_households) / 0.5"

TEXTBOX
5
550
115
696
Neighbourhood\n\n\nHeat network\n\n\nFinancial intervention\n\n\nOther intervention
11
0.0
1

CHOOSER
120
670
320
715
other_intervention
other_intervention
"none" "awareness campaign" "improve energy efficiency"
0

SLIDER
345
605
515
638
gas_tax_low_reduction
gas_tax_low_reduction
0
0.5
0.0
0.05
1
€/m3
HORIZONTAL

BUTTON
125
220
195
285
NIL
update-view
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
520
570
700
603
connection_fee_apartments
connection_fee_apartments
0
10000
6000.0
100
1
NIL
HORIZONTAL

SLIDER
520
605
700
638
connection_fee_lowrise
connection_fee_lowrise
0
15000
10000.0
100
1
NIL
HORIZONTAL

SWITCH
5
220
125
253
update-map?
update-map?
0
1
-1000

SWITCH
5
252
125
285
update-plots?
update-plots?
0
1
-1000

MONITOR
1225
935
1365
980
% collective heating
count households with [heating_system = \"collective\"] / total_households * 100
1
1
11

CHOOSER
120
580
320
625
heat_network_implementation
heat_network_implementation
"none" "corporation multi-family" "open to all"
0

SLIDER
520
640
700
673
awareness_savings
awareness_savings
0
1
0.15
0.05
1
NIL
HORIZONTAL

TEXTBOX
5
715
155
733
Conceptualisations
14
0.0
1

CHOOSER
120
735
320
780
decision_making
decision_making
"model of consumer behaviour" "all deliberate" "coin flip"
0

CHOOSER
120
780
320
825
energy_consumption_factors
energy_consumption_factors
"baseline" "income affects heat use" "no heterogeneity"
0

CHOOSER
345
675
515
720
energy_prices
energy_prices
"2023 regulated prices" "2021 prices" "2020 prices" "2019 prices"
1

MONITOR
1505
935
1645
980
Mean energy expense [€]
mean [energy_expenses] of households
0
1
11

MONITOR
1505
845
1645
890
Mean heat expense [€]
mean [heat_expenses] of households
0
1
11

MONITOR
1505
890
1645
935
Mean electric expense [€]
mean [electricity_expenses] of households
0
1
11

MONITOR
1645
845
1785
890
Mean 'gas' use [m3]
mean [heat_use] of households / 0.03517
0
1
11

MONITOR
1645
890
1785
935
Mean electricity use [kWh]
mean [electricity_use] of households / 0.0036
0
1
11

PLOT
925
340
1205
490
Heat expense
Month
€
0.0
60.0
0.0
10.0
true
true
"" ""
PENS
"Gas" 1.0 0 -16777216 true "" "plot mean [heat_expenses] of households with [building_connected? = false]"
"Net" 1.0 0 -7500403 true "" "ifelse count households with [building_connected? = true] > 0\n[plot mean [heat_expenses] of households with [building_connected? = true]]\n[plot mean [heat_expenses] of households]"
"Mean" 1.0 0 -2674135 true "" "plot mean [heat_expenses] of households"

PLOT
725
340
925
490
Heat expense per GJ
Month
€/GJ
0.0
60.0
0.0
10.0
true
true
"" ""
PENS
"Gas" 1.0 0 -16777216 true "" "plot mean [heat_expenses] of households with [building_connected? = false] / mean [heat_use] of households with [building_connected? = false]"
"Net" 1.0 0 -7500403 true "" "ifelse count households with [building_connected? = true] > 0\n[plot mean [heat_expenses] of households with [building_connected? = true] / mean [heat_use] of households with [building_connected? = true]]\n[plot mean [heat_expenses] of households / mean [heat_use] of households]"
"Mean" 1.0 0 -2674135 true "" "plot mean [heat_expenses] of households / mean [heat_use] of households"

MONITOR
405
875
520
920
Var costs gas
variable_costs_gas * (1 + VAT)
0
1
11

MONITOR
405
920
520
965
Var costs heat
variable_costs_heat
0
1
11

MONITOR
405
830
520
875
Var costs electricity
variable_costs_electricity * (1 + VAT)
0
1
11

MONITOR
520
830
635
875
Fixed costs electricity
fixed_costs_electricity * (1 + VAT)
0
1
11

MONITOR
520
875
635
920
Fixed costs gas
fixed_costs_gas * (1 + VAT)
0
1
11

MONITOR
520
920
635
965
Fixed costs heat
fixed_costs_heat
0
1
11

TEXTBOX
520
815
670
833
All prices incl VAT [€/GJ]
11
0.0
1

PLOT
5
980
205
1130
Lorenz curve energy expenses
NIL
NIL
0.0
100.0
0.0
100.0
false
true
"" ""
PENS
"lorenz" 1.0 0 -2674135 true "" "plot-pen-reset\nset-plot-pen-interval 100 / total_households\nplot 0\nforeach lorenz-points-ee plot"
"equal" 100.0 0 -16777216 true "plot 0\nplot 100" ""

PLOT
205
980
405
1130
Gini index energy expenses
Month
Gini
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"pen-0" 1.0 0 -13345367 true "" "plot (gini-index-reserve-ee / total_households) / 0.5"

MONITOR
405
980
470
1025
NIL
gini-EQ
2
1
11

MONITOR
535
980
600
1025
NIL
gini-income
2
1
11

MONITOR
470
980
535
1025
NIL
gini-ee
2
1
11

PLOT
925
940
1205
1090
Energy demand per label
Month
€
0.0
60.0
0.0
10.0
true
true
"" "if update-plots? = true [plot-energy-demand-labels]"
PENS

MONITOR
635
830
720
875
Heffingskorting
tax_reduction
0
1
11

SLIDER
345
640
515
673
gas_tax_high_increase
gas_tax_high_increase
0
0.5
0.0
0.05
1
€/m3
HORIZONTAL

SWITCH
520
675
700
708
include-extra-costs?
include-extra-costs?
1
1
-1000

MONITOR
1225
890
1365
935
% LIHC
count households with [LIHC? = true] / total_households * 100
1
1
11

TEXTBOX
5
750
155
825
Decision making method\n\n\nFactors influencing\nenergy consumption
11
0.0
1

PLOT
1005
1090
1285
1280
Energy expense per income group
Month
Expense (€/y)
0.0
60.0
0.0
10.0
true
true
"" "plot-energy-expense-incomes"
PENS

PLOT
1285
1090
1565
1280
Energy expense per ownership
Month
Expense (€/y)
0.0
60.0
0.0
10.0
true
true
"" "plot-energy-expense-ownership"
PENS

PLOT
725
1090
1005
1280
Energy quote per income group
Month
Energy quote
0.0
60.0
0.0
0.3
true
true
"" "plot-energy-quote-incomes"
PENS

@#$#@#$#@
## WHAT IS IT?

The model purpose is to explore inequalities, measured in terms of capabilities and capability conflicts, in households as a result of the deployment of geothermal heating systems. 
The model has been designed for scientists, industry professionals and policy advisors with the aim of evaluating various scenarios for technical and governance configurations of heat networks.

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.3.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="sociodemographic_validation" repetitions="10" runMetricsEveryStep="false">
    <setup>setup-map
setup-model</setup>
    <go>go</go>
    <timeLimit steps="1"/>
    <metric>total_households</metric>
    <metric>counts ; energy labels</metric>
    <metric>dwelling_counts</metric>
    <metric>household_counts</metric>
    <metric>LI</metric>
    <metric>LEQ</metric>
    <metric>HEQ</metric>
    <metric>LIHC</metric>
    <metric>LILEQ</metric>
    <metric>LILEQ-</metric>
    <metric>LILEQ+</metric>
    <metric>oLEQ</metric>
    <metric>rLEQ</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_expenses</metric>
    <metric>mean_energy_use</metric>
    <metric>count households with [heating_system = "individual"] / total_households</metric>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_25_buitenhof&quot;"/>
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-to-gas">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="electricity_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;decision strategy&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high">
      <value value="1.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-GHS?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.7"/>
      <value value="0.75"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="baseline_test1" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>LEQ</metric>
    <metric>HEQ</metric>
    <metric>LIHC</metric>
    <metric>LILEQ</metric>
    <metric>LILEQ-</metric>
    <metric>LILEQ+</metric>
    <metric>oLEQ</metric>
    <metric>rLEQ</metric>
    <metric>gini-EQ</metric>
    <metric>gini-income</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
      <value value="&quot;wijk_25_buitenhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-to-gas">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="electricity_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high">
      <value value="1.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenarios_test1" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>LEQ</metric>
    <metric>HEQ</metric>
    <metric>LIHC</metric>
    <metric>LILEQ</metric>
    <metric>LILEQ-</metric>
    <metric>LILEQ+</metric>
    <metric>oLEQ</metric>
    <metric>rLEQ</metric>
    <metric>gini-EQ</metric>
    <metric>gini-income</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
      <value value="&quot;corporation multi-family&quot;"/>
      <value value="&quot;open to all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;energy tax&quot;"/>
      <value value="&quot;vouchers&quot;"/>
      <value value="&quot;energy tax and vouchers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;awareness campaign&quot;"/>
      <value value="&quot;improve energy efficiency&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-to-gas">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="electricity_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="baseline_test2_pre-prices" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>LEQ</metric>
    <metric>HEQ</metric>
    <metric>LIHC</metric>
    <metric>LILEQ</metric>
    <metric>LILEQ-</metric>
    <metric>LILEQ+</metric>
    <metric>oLEQ</metric>
    <metric>rLEQ</metric>
    <metric>gini-EQ</metric>
    <metric>gini-income</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
      <value value="&quot;wijk_25_buitenhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-to-gas">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="electricity_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high">
      <value value="1.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="baseline_test3_post-prices" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>LEQ</metric>
    <metric>HEQ</metric>
    <metric>LIHC</metric>
    <metric>LILEQ</metric>
    <metric>LILEQ-</metric>
    <metric>LILEQ+</metric>
    <metric>oLEQ</metric>
    <metric>rLEQ</metric>
    <metric>gini-EQ</metric>
    <metric>gini-income</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
      <value value="&quot;wijk_25_buitenhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
      <value value="&quot;2021 prices&quot;"/>
      <value value="&quot;2020 prices&quot;"/>
      <value value="&quot;2019 prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-to-gas">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="electricity_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high">
      <value value="1.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenarios_test2" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>LEQ</metric>
    <metric>HEQ</metric>
    <metric>LIHC</metric>
    <metric>LILEQ</metric>
    <metric>LILEQ-</metric>
    <metric>LILEQ+</metric>
    <metric>oLEQ</metric>
    <metric>rLEQ</metric>
    <metric>gini-EQ</metric>
    <metric>gini-income</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
      <value value="&quot;corporation multi-family&quot;"/>
      <value value="&quot;open to all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;energy tax&quot;"/>
      <value value="&quot;vouchers&quot;"/>
      <value value="&quot;energy tax and vouchers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;awareness campaign&quot;"/>
      <value value="&quot;improve energy efficiency&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
      <value value="&quot;all deliberate&quot;"/>
      <value value="&quot;coin flip&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-to-gas">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="electricity_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_evaludation_prices" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
      <value value="&quot;open to all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
      <value value="&quot;income affects heat use&quot;"/>
      <value value="&quot;no heterogeneity&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
      <value value="&quot;2021 prices&quot;"/>
      <value value="&quot;2020 prices&quot;"/>
      <value value="&quot;2019 prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="electricity_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high">
      <value value="1.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_evaludation_small" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
      <value value="&quot;2021 prices&quot;"/>
      <value value="&quot;2020 prices&quot;"/>
      <value value="&quot;2019 prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low_reduction">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high_increase">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="include-extra-costs?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_evaludation_consumption" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
      <value value="&quot;wijk_25_buitenhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
      <value value="&quot;income affects heat use&quot;"/>
      <value value="&quot;no heterogeneity&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="electricity_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high">
      <value value="1.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_evaludation_choice" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;open to all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;vouchers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;awareness campaign&quot;"/>
      <value value="&quot;improve energy efficiency&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
      <value value="&quot;all deliberate&quot;"/>
      <value value="&quot;coin flip&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="electricity_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_scenarios_vouchers_voorhof" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
      <value value="&quot;corporation multi-family&quot;"/>
      <value value="&quot;open to all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;vouchers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;awareness campaign&quot;"/>
      <value value="&quot;improve energy efficiency&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="electricity_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_scenarios_vouchers_buitenhof" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_25_buitenhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
      <value value="&quot;corporation multi-family&quot;"/>
      <value value="&quot;open to all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;vouchers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;awareness campaign&quot;"/>
      <value value="&quot;improve energy efficiency&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="electricity_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_parametrization_awareness" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;awareness campaign&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="electricity_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_price_increase">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_1_energy_tax" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
      <value value="&quot;open to all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;energy tax&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
      <value value="&quot;2021 prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low_reduction">
      <value value="0.05"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high_increase">
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_2_evaludation_prices2" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
      <value value="&quot;open to all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
      <value value="&quot;2021 prices&quot;"/>
      <value value="&quot;2020 prices&quot;"/>
      <value value="&quot;2019 prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low_reduction">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high_increase">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="include-extra-costs?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_2_evaludation_consumption" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
      <value value="&quot;income affects heat use&quot;"/>
      <value value="&quot;no heterogeneity&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low_reduction">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high_increase">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="include-extra-costs?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_2_parametrization_awareness" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;awareness campaign&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low_reduction">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high_increase">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="include-extra-costs?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_2_evaludation_extra_costs" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
      <value value="&quot;2021 prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low_reduction">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high_increase">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="include-extra-costs?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_2_scenarios_vouchers" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
      <value value="&quot;corporation multi-family&quot;"/>
      <value value="&quot;open to all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;vouchers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;awareness campaign&quot;"/>
      <value value="&quot;improve energy efficiency&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low_reduction">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high_increase">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="include-extra-costs?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_2_scenarios_energy_tax" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
      <value value="&quot;corporation multi-family&quot;"/>
      <value value="&quot;open to all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;energy tax&quot;"/>
      <value value="&quot;energy tax and vouchers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;awareness campaign&quot;"/>
      <value value="&quot;improve energy efficiency&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low_reduction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high_increase">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="include-extra-costs?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_2_evaludation_choice" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_24_voorhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;open to all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;vouchers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;awareness campaign&quot;"/>
      <value value="&quot;improve energy efficiency&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
      <value value="&quot;all deliberate&quot;"/>
      <value value="&quot;coin flip&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low_reduction">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high_increase">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="include-extra-costs?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_2_scenarios_vouchers_buitenhof" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_25_buitenhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
      <value value="&quot;corporation multi-family&quot;"/>
      <value value="&quot;open to all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;vouchers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
      <value value="&quot;awareness campaign&quot;"/>
      <value value="&quot;improve energy efficiency&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low_reduction">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high_increase">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="include-extra-costs?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v1_2_evaludation_prices2_buitenhof" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total_households</metric>
    <metric>mean_income</metric>
    <metric>mean_energy_use</metric>
    <metric>mean_heat_use</metric>
    <metric>mean_heat_expenses</metric>
    <metric>mean_electricity_expenses</metric>
    <metric>mean_EQ</metric>
    <metric>fraction_renters</metric>
    <metric>energy_poverty</metric>
    <metric>ginis</metric>
    <metric>fraction_renters_ep</metric>
    <metric>mean_energy_use_ep</metric>
    <metric>mean_income_ep</metric>
    <metric>income_groups_ep</metric>
    <metric>household_type_ep</metric>
    <metric>dwelling_category_ep</metric>
    <metric>energy_labels_ep</metric>
    <metric>ep_homeownership</metric>
    <metric>ep_income_groups</metric>
    <metric>ep_household_types</metric>
    <metric>ep_dwelling_categories</metric>
    <metric>ep_energy_labels</metric>
    <metric>fraction_connected</metric>
    <metric>fraction_unaffordable</metric>
    <metric>fraction_voucher</metric>
    <metric>fraction_renters_hn</metric>
    <metric>mean_energy_use_hn</metric>
    <metric>mean_income_hn</metric>
    <metric>income_groups_hn</metric>
    <metric>household_type_hn</metric>
    <metric>dwelling_category_hn</metric>
    <metric>energy_labels_hn</metric>
    <enumeratedValueSet variable="buurt">
      <value value="&quot;wijk_25_buitenhof&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat_network_implementation">
      <value value="&quot;none&quot;"/>
      <value value="&quot;open to all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="financial_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="other_intervention">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decision_making">
      <value value="&quot;model of consumer behaviour&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_consumption_factors">
      <value value="&quot;baseline&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-map?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-building-feature">
      <value value="&quot;construction year&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="show-household-feature">
      <value value="&quot;energy label&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_prices">
      <value value="&quot;2023 regulated prices&quot;"/>
      <value value="&quot;2021 prices&quot;"/>
      <value value="&quot;2020 prices&quot;"/>
      <value value="&quot;2019 prices&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="heat-cost-relative-to-max">
      <value value="0.92"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-use">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share_collective_system">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_apartments">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="connection_fee_lowrise">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="awareness_savings">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_low_reduction">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gas_tax_high_increase">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="include-extra-costs?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
1
@#$#@#$#@
